@@ -64,7 +64,6 @@ CantorPart::CantorPart( QWidget *parentWidget, QObject *parent, const QStringLis
 
     m_showBackendHelp=0;
     m_initProgressDlg=0;
-    m_scriptEditor=0;
     m_statusBarBlocked=false;
 
     kDebug()<<"Created a CantorPart";
@@ -99,6 +98,11 @@ CantorPart::CantorPart( QWidget *parentWidget, QObject *parent, const QStringLis
     KStandardAction::saveAs(this, SLOT(fileSaveAs()), actionCollection());
     m_save = KStandardAction::save(this, SLOT(save()), actionCollection());
 
+    KAction* latexExport=new KAction(i18n("Export to LaTex"), actionCollection());
+    actionCollection()->addAction("file_export_latex", latexExport);
+    latexExport->setIcon(KIcon("document-export"));
+    connect(latexExport, SIGNAL(triggered()), this, SLOT(exportToLatex()));
+
     KStandardAction::print(this, SLOT(print()), actionCollection());
 
     KStandardAction::zoomIn(m_worksheet, SLOT(zoomIn()), actionCollection());
@@ -119,10 +123,10 @@ CantorPart::CantorPart( QWidget *parentWidget, QObject *parent, const QStringLis
     actionCollection()->addAction("enable_highlighting", m_highlight);
     connect(m_highlight, SIGNAL(toggled(bool)), m_worksheet, SLOT(enableHighlighting(bool)));
 
-    m_tabcompletion=new KToggleAction(i18n("Tab Completion"), actionCollection());
-    m_tabcompletion->setChecked(Settings::self()->tabCompletionDefault());
-    actionCollection()->addAction("enable_tabcompletion", m_tabcompletion);
-    connect(m_tabcompletion, SIGNAL(toggled(bool)), m_worksheet, SLOT(enableTabCompletion(bool)));
+    m_completion=new KToggleAction(i18n("Completion"), actionCollection());
+    m_completion->setChecked(Settings::self()->completionDefault());
+    actionCollection()->addAction("enable_completion", m_completion);
+    connect(m_completion, SIGNAL(toggled(bool)), m_worksheet, SLOT(enableCompletion(bool)));
 
     m_exprNumbering=new KToggleAction(i18n("Line Numbers"), actionCollection());
     m_exprNumbering->setChecked(Settings::self()->expressionNumberingDefault());
@@ -144,6 +148,11 @@ CantorPart::CantorPart( QWidget *parentWidget, QObject *parent, const QStringLis
     actionCollection()->addAction("insert_entry",  insertEntry);
     connect(insertEntry, SIGNAL(triggered()), m_worksheet, SLOT(insertEntry()));
 
+    KAction* removeCurrent=new KAction(i18n("Remove current Entry"), actionCollection());
+    removeCurrent->setShortcut(Qt::ShiftModifier + Qt::Key_Delete);
+    actionCollection()->addAction("remove_current", removeCurrent);
+    connect(removeCurrent, SIGNAL(triggered()), m_worksheet, SLOT(removeCurrentEntry()));
+
     m_showBackendHelp=new KAction(i18n("Show %1 Help", b->name()) , actionCollection());
     m_showBackendHelp->setIcon(KIcon("help-contents"));
     actionCollection()->addAction("backend_help", m_showBackendHelp);
@@ -158,6 +167,12 @@ CantorPart::CantorPart( QWidget *parentWidget, QObject *parent, const QStringLis
     showEditor->setChecked(false);
     actionCollection()->addAction("show_editor", showEditor);
     connect(showEditor, SIGNAL(toggled(bool)), this, SLOT(showScriptEditor(bool)));
+    showEditor->setEnabled(b->extensions().contains("ScriptExtension"));
+
+    KAction* showCompletion=new KAction(i18n("Show Completion"), actionCollection());
+    actionCollection()->addAction("show_completion", showCompletion);
+    showCompletion->setShortcut(Qt::Key_Tab); //Qt::CTRL + Qt::Key_Space);
+    connect(showCompletion, SIGNAL(triggered()), m_worksheet, SLOT(showCompletion()));
 
 
     // set our XML-UI resource file
@@ -174,6 +189,11 @@ CantorPart::CantorPart( QWidget *parentWidget, QObject *parent, const QStringLis
 
 CantorPart::~CantorPart()
 {
+    if (m_scriptEditor)
+    {
+        disconnect(m_scriptEditor, SIGNAL(destroyed()), this, SLOT(scriptEditorClosed()));
+        delete m_scriptEditor;
+    }
 }
 
 void CantorPart::setReadWrite(bool rw)
@@ -206,7 +226,7 @@ KAboutData *CantorPart::createAboutData()
     // the non-i18n name here must be the same as the directory in
     // which the part's rc file is installed ('partrcdir' in the
     // Makefile)
-    KAboutData *aboutData = new KAboutData("cantorpart",  "cantor",  ki18n("CantorPart"), "0.1");
+    KAboutData *aboutData = new KAboutData("cantorpart",  "cantor",  ki18n("CantorPart"), "0.2");
     aboutData->addAuthor(ki18n("Alexander Rieder"), KLocalizedString(), "alexanderrieder@gmail.com");
     return aboutData;
 }
@@ -272,6 +292,20 @@ void CantorPart::fileSaveAs()
     updateCaption();
 }
 
+void CantorPart::exportToLatex()
+{
+    // this slot is called whenever the File->Save As menu is selected,
+    QString filter=i18n("*.tex|LaTex Document");
+
+    QString file_name = KFileDialog::getSaveFileName(KUrl(), filter, widget());
+
+    if (file_name.isEmpty() == false)
+    {
+        int exportImages=KMessageBox::questionYesNo(widget(), i18n("Do you also want to export the images?"), i18n("Question - Cantor"));
+        m_worksheet->saveLatex( file_name , exportImages==KMessageBox::Yes);
+    }
+}
+
 void CantorPart::guiActivateEvent( KParts::GUIActivateEvent * event )
 {
     KParts::ReadWritePart::guiActivateEvent(event);
@@ -450,7 +484,7 @@ void CantorPart::adjustGuiToSession()
 #else
     m_typeset->setVisible(false);
 #endif
-    m_tabcompletion->setVisible(m_worksheet->session()->backend()->capabilities().testFlag(Cantor::Backend::TabCompletion));
+    m_completion->setVisible(m_worksheet->session()->backend()->capabilities().testFlag(Cantor::Backend::Completion));
 
     //this is 0 on the first call
     if(m_showBackendHelp)
@@ -499,23 +533,33 @@ void CantorPart::print()
 
 void CantorPart::showScriptEditor(bool show)
 {
-    Cantor::Backend* backend=m_worksheet->session()->backend();
-    if(!backend->extensions().contains("ScriptExtension"))
-    {
-        KMessageBox::error(widget(), i18n("This backend does not support scripts."), i18n("Error - Cantor"));
-        return;
-    }
-
     if(show)
     {
-        Cantor::ScriptExtension* scriptE=dynamic_cast<Cantor::ScriptExtension*>(backend->extension("ScriptExtension"));
-        m_scriptEditor=new ScriptEditorWidget(scriptE->scriptFileFilter());
+        if (m_scriptEditor)
+        {
+            return;
+        }
+        Cantor::ScriptExtension* scriptE=dynamic_cast<Cantor::ScriptExtension*>(m_worksheet->session()->backend()->extension("ScriptExtension"));
+        if (!scriptE)
+        {
+            return;
+        }
+        m_scriptEditor=new ScriptEditorWidget(scriptE->scriptFileFilter(), widget()->window());
         connect(m_scriptEditor, SIGNAL(runScript(const QString&)), this, SLOT(runScript(const QString&)));
+        connect(m_scriptEditor, SIGNAL(destroyed()), this, SLOT(scriptEditorClosed()));
         m_scriptEditor->show();
     }else
     {
-        m_scriptEditor->deleteLater();
-        m_scriptEditor=0;
+        delete m_scriptEditor;
+    }
+}
+
+void CantorPart::scriptEditorClosed()
+{
+    QAction* showEditor = actionCollection()->action("show_editor");
+    if (showEditor)
+    {
+        showEditor->setChecked(false);
     }
 }
 
