@@ -1,5 +1,5 @@
 /*************************************************************************************
- *  Copyright (C) 2007 by Aleix Pol <aleixpol@gmail.com>                             *
+ *  Copyright (C) 2007 by Aleix Pol <aleixpol@kde.org>                               *
  *                                                                                   *
  *  This program is free software; you can redistribute it and/or                    *
  *  modify it under the terms of the GNU General Public License                      *
@@ -23,12 +23,15 @@
 
 #include "analitzaexport.h"
 
+namespace Analitza
+{
+
 class ExpressionWriter;
 
 /**
  *	\internal
- *	The atomic mean of the expression trees. Should never used alone, always inherited.
- *	@author Aleix Pol <aleixpol@gmail.com>
+ *	Abstract expression tree node
+ *	@author Aleix Pol <aleixpol@kde.org>  
  */
 
 //FIXME: Check for public -> protected on some members
@@ -41,9 +44,12 @@ public:
 		value,		/**< Describes an object as a value. */
 		variable,	/**< Describes an object as a variable. */
 		vector,		/**< Describes an object as a vector. */
+		list,		/**< Describes an object as a list. */
+		apply,		/**< Describes an object as an application. */
 		oper,		/**< Describes an object as an operator. */
 		container	/**< Describes an object as a container. */
 	};
+	typedef QMap<QString, Object**> ScopeInformation;
 	
 	/** Object destructor. Does nothing. */
 	virtual ~Object() { /*qDebug() << "Destroying " << this;*/}
@@ -51,6 +57,9 @@ public:
 	/** Returns the object type of the object */
 	enum ObjectType type() const { return m_type; }
 	
+	/** Returns whether it is an apply or not. */
+	bool isApply() const { return m_type==apply; }
+	
 	/** Returns whether it is a container or not. */
 	bool isContainer() const { return m_type==container; }
 	
@@ -60,18 +69,13 @@ public:
 	/** Converts a @p tag to a type. */
 	static enum ObjectType whatType(const QString& tag); //FIXME: Needed?
 	
-	/** Returns whether it is a correct object or not */
+	/** Returns some string depending on the visior */
 	virtual QString visit(ExpressionWriter* exp) const =0;
 	
-	/** Returns whether it is a correct object or not */
-	virtual bool isCorrect() const = 0;
-	
-	virtual void negate() {}
-	
 	virtual bool isZero() const { return false; }
 	
 	/** 
-		@p pattern is the tree that we will compare to,
+		@p exp is the tree that we will compare to,
 		@p found is where we will pass the variables store the results.
 		
 		It will return whether the object follows the @p pattern structure.
@@ -81,51 +85,19 @@ public:
 	/** @returns a new and equal instance of the tree. */
 	virtual Object* copy() const =0;
 	
+	/**
+	*	Decorates the tree with scope information
+	*	@returns whether unresolved variables were found
+	*/
+	virtual bool decorate(const ScopeInformation& scope)=0;
+	
 protected:
 	/** Creates an object with a @p t type */
 	Object(enum ObjectType t) : m_type(t) {}
 	
 	/** Specifies the Object type. */
-	enum ObjectType m_type;
-};
-
-/** A variable object, name refers to MathML standard. */
-class ANALITZA_EXPORT Ci : public Object
-{
-	public:
-		/** Constructor. Creates a variable with a @p b name */
-		explicit Ci(const QString& b) : Object(variable), m_name(b), m_function(false) {}
-		
-		/** Sets a @p n name to a variable */
-		void setName(const QString& n) { m_name=n; }
-		
-		/** Returns the variable name */
-		QString name() const { return m_name; }
-		
-		/** Returns whether @p var name is equal to this variable one. */
-		bool operator==(const Ci& var) const { return var.m_name==m_name; }
-		
-		/** Sets whether it is a function. */
-		void setFunction(bool f) { m_function=f; }
-		
-		/** Returns whether it is a variable that has to be a function */
-		bool isFunction() const { return m_function; }
-		
-		/** Returns the MathML representation of the variable */
-		QString toMathML() const;
-		
-		/** Returns the HTML representation of the variable */
-		QString toHtml() const { return QString("<span class='%1'>%2</span>").arg(m_function ? "func" : "var").arg(m_name); }
-		
-		/** Returns whether it is a correct object. */
-		bool isCorrect() const { return m_type==Object::variable && !m_name.isEmpty(); }
-		
-		virtual QString visit(ExpressionWriter*) const;
-		virtual bool matches(const Object* pattern, QMap<QString, const Object*>* found) const;
-		virtual Object* copy() const;
-	private:
-		QString m_name;
-		bool m_function;
+	const ObjectType m_type;
 };
 
+}
 #endif
