@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright 2001-2009 Anne-Marie Mahfouf <annma@kde.org>                *
+ *   Copyright 2001-2010 Anne-Marie Mahfouf <annma@kde.org>                *
  *                                                                         *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -50,7 +50,8 @@
 #include <KGlobal>
 #include <KSharedConfig>
 
-#include <knewstuff2/engine.h>
+#include <knewstuff3/downloaddialog.h>
+#include <knewstuff3/uploaddialog.h>
 
 KHangMan::KHangMan()
         : KXmlGuiWindow(), m_currentLevel(-1),
@@ -89,7 +90,16 @@ void KHangMan::setupActions()
     KAction *newAct = KStandardAction::openNew(this, SLOT(slotNewGame()),
                                        actionCollection());
     newAct->setToolTip(i18n( "Play with a new word" ));
-
+    
+    KAction* uploadFile =new KAction(this);
+    actionCollection()->addAction("file_upload", uploadFile);
+    uploadFile->setIcon(KIcon("get-hot-new-stuff"));
+    uploadFile->setText(i18n("&Upload KHangMan file..."));
+    uploadFile->setWhatsThis(i18n("Share the current KHangMan file with other users."));
+    uploadFile->setToolTip(uploadFile->whatsThis());
+    uploadFile->setStatusTip(uploadFile->whatsThis());
+    connect(uploadFile, SIGNAL(triggered()), this, SLOT(slotUploadFile()));
+    
     KAction* fileOpen = KStandardAction::open(this, SLOT(slotFileOpen()), actionCollection());
     fileOpen->setWhatsThis(i18n("Opens an existing vocabulary document"));
     fileOpen->setToolTip(fileOpen->whatsThis());
@@ -214,15 +224,15 @@ void KHangMan::setLanguages()
     if (m_languages.isEmpty()) {
         qApp->closeAllWindows();
     }
-    //find duplicated entries in KDEDIR and KDEHOME
+    // find duplicated entries in KDEDIR and KDEHOME
 
     // Write the present languages in config so they cannot be downloaded.
     // FIXME: use pre-seeding here
     KConfigGroup cg( KGlobal::config() ,"KNewStuff2");
     for (int i=0;  i<m_languages.count(); ++i) {
-        //QString tmp = cg.readEntry(m_languages[i]);
-       // if (!tmp)
-            cg.writeEntry(m_languages[i], QDate::currentDate().toString(Qt::ISODate));
+        // QString tmp = cg.readEntry(m_languages[i]);
+        // if (!tmp)
+        cg.writeEntry(m_languages[i], QDate::currentDate().toString(Qt::ISODate));
     }
     cg.config()->sync();
     
@@ -245,7 +255,7 @@ void KHangMan::setLanguages()
 void KHangMan::loadSettings()
 {
     // Language //TODO is selectedLanguage necessary??? only used here
-    if (m_languages.isEmpty()){
+    if (m_languages.isEmpty()) {
         qApp->closeAllWindows();
     }
     selectedLanguage = Prefs::selectedLanguage();
@@ -290,7 +300,7 @@ void KHangMan::loadLevels()
         titles = SharedKvtmlFiles::titles(Prefs::selectedLanguage());
     }
 
-    if (levels.isEmpty()){
+    if (levels.isEmpty()) {
         qApp->closeAllWindows();
     }
     m_languageAction->setCurrentItem(m_languages.indexOf(Prefs::selectedLanguage()));
@@ -324,7 +334,7 @@ void KHangMan::loadLevels()
 
 void KHangMan::optionsPreferences()
 {
-    if ( KConfigDialog::showDialog( "settings" ) )  {
+    if ( KConfigDialog::showDialog( "settings" ) ) {
         ui_language.kcfg_AccentedLetters->setEnabled(m_view->accentedLetters());
         return;
     }
@@ -369,8 +379,9 @@ void KHangMan::updateSettings()
 void KHangMan::slotDownloadNewStuff()
 {
     // delete all the entry pointers that are returned
-    qDeleteAll(KNS::Engine::download());
-
+    //qDeleteAll(KNS3::DownloadDialog);
+    KNS3::DownloadDialog dialog("khangman.knsrc", this);
+    dialog.exec();
     SharedKvtmlFiles::sortDownloadedFiles();
     //look for languages dirs installed
     setLanguages();
@@ -536,7 +547,7 @@ void KHangMan::slotNewGame()
 void KHangMan::slotFileOpen()
 {
     KUrl url = KFileDialog::getOpenUrl(QString(), KEduVocDocument::pattern(KEduVocDocument::Reading), this, i18n("Open Vocabulary Document"));
-    if ( url.isValid() )  {
+    if ( url.isValid() ) {
         if(url.isLocalFile())
             Prefs::setLevelFile(url.toLocalFile());
         else
@@ -548,6 +559,19 @@ void KHangMan::slotFileOpen()
     }
 }
 
+void KHangMan::slotUploadFile()
+{
+    // get the doc title
+    KEduVocDocument *doc = new KEduVocDocument(this);
+    doc->open(Prefs::levelFile());
+    // upload
+    KNS3::UploadDialog dialog(this);
+    dialog.setUploadFile(Prefs::levelFile());
+    // preset the doc title in the dialog title field
+    dialog.setUploadName(doc->title());
+    dialog.exec();
+}
+
 void KHangMan::slotSetHint(bool hint)
 {
     Prefs::setHint(hint);
