@@ -23,19 +23,18 @@
 #include <config-kstars.h>
 
 #include "tools/observinglist.h"
+#include "comast/equipmentwriter.h"
+#include "comast/observeradd.h"
 
 // forward declaration is enough. We only need pointers
 class QPalette;
 class KActionMenu;
-class KLed;
 
 class dms;
 class KStarsData;
-class KStarsSplash;
 class SkyMap;
 class GeoLocation;
 class FindDialog;
-class InfoBoxes;
 class TimeStepBox;
 
 class INDIMenu;
@@ -44,12 +43,16 @@ class imagesequence;
 class AltVsTime;
 class LCGenerator;
 class WUTDialog;
+class AstroCalc;
 class SkyCalendar;
 class ScriptBuilder;
 class PlanetViewer;
 class JMoonTool;
-class ImageViewer;
 class FlagManager;
+class ObservingList;
+class EquipmentWriter;
+class ObserverAdd;
+class Execute;
 
 class OpsCatalog;
 class OpsGuides;
@@ -82,11 +85,11 @@ class KStars : public KXmlGuiWindow
 
 private:
     /**
-     *@short Constructor.
-     *@param doSplash should the splash panel be displayed during
-     *initialization.
-     *@param startClockRunning should the clock be running on startup?
-     *@param startDateString date (in string representation) to start running from.
+     * @short Constructor.
+     * @param doSplash should the splash panel be displayed during
+     * initialization.
+     * @param startClockRunning should the clock be running on startup?
+     * @param startDateString date (in string representation) to start running from.
      *
      * @todo Refer to documentation on date format.
      */
@@ -95,541 +98,426 @@ private:
     static KStars *pinstance; // Pointer to an instance of KStars
 
 public:
-
     /**
-     *@short Create an instance of this class. Destroy any previous instance
-     *@param doSplash
-     *@param clockrunning
-     *@param startDateString
-     *@note See KStars::KStars for details on parameters
-     *@return a pointer to the instance
+     * @short Create an instance of this class. Destroy any previous instance
+     * @param doSplash
+     * @param clockrunning
+     * @param startDateString
+     * @note See KStars::KStars for details on parameters
+     * @return a pointer to the instance
      */
     static KStars *createInstance( bool doSplash, bool clockrunning = true, const QString &startDateString = QString() );
 
-    /**
-     *@return a pointer to the instance of this class
-     */
+    /** @return a pointer to the instance of this class */
     inline static KStars *Instance() { return pinstance; }
 
-    /**Destructor.  Synchs config file.  Deletes objects.
-    	*/
-    ~KStars();
+    /**Destructor.  Synchs config file.  Deletes objects. */
+    virtual ~KStars();
 
-    /**@return pointer to KStarsData object which contains application data.
-    	*/
-    KStarsData* data();
+    /**@return pointer to KStarsData object which contains application data. */
+    KStarsData* data() { return kstarsData; }
 
-    /**@return pointer to the local sidereal time.
-    	*/
-    dms* LST();
+    /**@return pointer to SkyMap object which is the sky display widget. */
+    SkyMap* map() { return skymap; }
 
-    /**@return pointer to SkyMap object which is the sky display widget.
-    	*/
-    SkyMap* map();
+    ObservingList* observingList() { return obsList; }
 
-    ObservingList* observingList();
+    Execute* getExecute();
 
-    ImageViewer* addImageViewer(const KUrl &url, const QString &message );
-    void removeImageViewer( ImageViewer* );
-
-    /**@return pointer to GeoLocation object which is the current geographic location.
-    	*/
-    GeoLocation* geo();
-
-    /**@return pointer to InfoBoxes object.
-    	*/
-    InfoBoxes* infoBoxes();
-
-    inline KLed* diskLED() { return m_DiskLED; }
-
-    /**@return pointer to the INDI driver
-    	*/
+    /**@return pointer to the INDI driver */
     INDIDriver* indiDriver() { return indidriver; }
 
-    /**@return pointer to the INDI menu
-    	*/
+    /**@return pointer to the INDI menu */
     INDIMenu* indiMenu() { return indimenu; }
 
-    /** Establish the INDI system. No GUI
-    	*/
+    /** Establish the INDI system. No GUI */
     void establishINDI();
 
     /**Add an item to the color-scheme action manu
-    	*@param name The name to use in the menu
-    	*@param actionName The internal name for the action (derived from filename)
-    	*/
+     * @param name The name to use in the menu
+     * @param actionName The internal name for the action (derived from filename)
+     */
     void addColorMenuItem( const QString &name, const QString &actionName );
 
     /**Remove an item from the color-scheme action manu
-    	*@param actionName The internal name of the action (derived from filename)
-    	*/
+     * @param actionName The internal name of the action (derived from filename)
+     */
     void removeColorMenuItem( const QString &actionName );
 
     /**@short Apply config options throughout the program.
-    	*In most cases, options are set in the "Options" object directly, 
-    	*but for some things we have to manually react to config changes.
-        *@param doApplyFocus If true, then focus posiiton will be set 
-        *from config file
-    	*/
+     * In most cases, options are set in the "Options" object directly,
+     * but for some things we have to manually react to config changes.
+     * @param doApplyFocus If true, then focus posiiton will be set
+     * from config file
+     */
     void applyConfig( bool doApplyFocus = true );
 
 public Q_SLOTS:
     /**DBUS interface function.
-    	*Set focus to given Ra/Dec coordinates 
-    	*@param ra the Right Ascension coordinate for the focus (in Hours)
-    	*@param dec the Declination coordinate for the focus (in Degrees)
-    	*/
+     * Set focus to given Ra/Dec coordinates
+     * @param ra the Right Ascension coordinate for the focus (in Hours)
+     * @param dec the Declination coordinate for the focus (in Degrees)
+     */
     Q_SCRIPTABLE Q_NOREPLY void setRaDec( double ra, double dec );
 
     /**DBUS interface function.
-    	*Set focus to given Alt/Az coordinates. 
-    	*@param alt the Altitude coordinate for the focus (in Degrees)
-    	*@param az the Azimuth coordinate for the focus (in Degrees)
-    	*/
+     * Set focus to given Alt/Az coordinates.
+     * @param alt the Altitude coordinate for the focus (in Degrees)
+     * @param az the Azimuth coordinate for the focus (in Degrees)
+     */
     Q_SCRIPTABLE Q_NOREPLY void setAltAz(double alt, double az);
 
     /**DBUS interface function.
-    	*Point in the direction described by the string argument.  
-    	*@param direction either an object name, a compass direction (e.g., "north"), or "zenith"
-    	*/
+     * Point in the direction described by the string argument.
+     * @param direction either an object name, a compass direction (e.g., "north"), or "zenith"
+     */
     Q_SCRIPTABLE Q_NOREPLY void lookTowards( const QString &direction );
 
     /**DBUS interface function.
-    	*Add a name label to the named object
-    	*@param name the name of the object to which the label will be attached
-    	*/
+     * Add a name label to the named object
+     * @param name the name of the object to which the label will be attached
+     */
     Q_SCRIPTABLE Q_NOREPLY void addLabel( const QString &name );
 
     /**DBUS interface function.
-    	*Remove a name label from the named object
-    	*@param name the name of the object from which the label will be removed
-    	*/
+     * Remove a name label from the named object
+     * @param name the name of the object from which the label will be removed
+     */
     Q_SCRIPTABLE Q_NOREPLY void removeLabel( const QString &name );
 
     /**DBUS interface function.
-    	*Add a trail to the named solar system body
-    	*@param name the name of the body to which the trail will be attached
-    	*/
+     * Add a trail to the named solar system body
+     * @param name the name of the body to which the trail will be attached
+     */
     Q_SCRIPTABLE Q_NOREPLY void addTrail( const QString &name );
 
     /**DBUS interface function.
-    	*Remove a trail from the named solar system body
-    	*@param name the name of the object from which the trail will be removed
-    	*/
+     * Remove a trail from the named solar system body
+     * @param name the name of the object from which the trail will be removed
+     */
     Q_SCRIPTABLE Q_NOREPLY void removeTrail( const QString &name );
 
     /**DBUS interface function.  Zoom in one step. */
-    Q_SCRIPTABLE Q_NOREPLY void zoomIn() { slotZoomIn(); }
+    Q_SCRIPTABLE Q_NOREPLY void zoomIn();
 
     /**DBUS interface function.  Zoom out one step. */
-    Q_SCRIPTABLE Q_NOREPLY void zoomOut(){ slotZoomOut(); }
+    Q_SCRIPTABLE Q_NOREPLY void zoomOut();
 
     /**DBUS interface function.  reset to the default zoom level. */
-    Q_SCRIPTABLE Q_NOREPLY void defaultZoom() { slotDefaultZoom(); }
+    Q_SCRIPTABLE Q_NOREPLY void defaultZoom();
 
-    /**DBUS interface function.  Set zoom level to specified value.
-    	*@param z the zoom level.  Units are pixels per radian.
-    	*/
+    /** DBUS interface function. Set zoom level to specified value.
+     *  @param z the zoom level. Units are pixels per radian. */
     Q_SCRIPTABLE Q_NOREPLY void zoom(double z);
 
     /**DBUS interface function.  Set local time and date.
-    	*@param yr year of date
-    	*@param mth month of date
-    	*@param day day of date
-    	*@param hr hour of time
-    	*@param min minute of time
-    	*@param sec second of time
-    	*/
+     * @param yr year of date
+     * @param mth month of date
+     * @param day day of date
+     * @param hr hour of time
+     * @param min minute of time
+     * @param sec second of time
+     */
     Q_SCRIPTABLE Q_NOREPLY void setLocalTime(int yr, int mth, int day, int hr, int min, int sec);
 
     /**DBUS interface function.  Delay further execution of DBUS commands.
-    	*@param t number of seconds to delay
-    	*/
+     * @param t number of seconds to delay
+     */
     Q_SCRIPTABLE Q_NOREPLY void waitFor( double t );
 
     /**DBUS interface function.  Pause further DBUS execution until a key is pressed.
-    	*@param k the key which will resume DBUS execution
-    	*/
+     * @param k the key which will resume DBUS execution
+     */
     Q_SCRIPTABLE Q_NOREPLY void waitForKey( const QString &k );
 
     /**DBUS interface function.  Toggle tracking.
-    	*@param track engage tracking if true; else disengage tracking
-    	*/
+     * @param track engage tracking if true; else disengage tracking
+     */
     Q_SCRIPTABLE Q_NOREPLY void setTracking( bool track );
 
     /**DBUS interface function.  modify a view option.
-    	*@param option the name of the option to be modified
-    	*@param value the option's new value
-    	*/
+     * @param option the name of the option to be modified
+     * @param value the option's new value
+     */
     Q_SCRIPTABLE Q_NOREPLY void changeViewOption( const QString &option, const QString &value );
 
     /**DBUS interface function.
-    	*@param name the name of the option to query
-    	*@return the current value of the named option
-    	*/
+     * @param name the name of the option to query
+     * @return the current value of the named option
+     */
     QString getOption( const QString &name );
 
     /**DBUS interface function.  Read config file.
-    	*This function is useful for restoring the user settings from the config file, 
-    	*after having modified the settings in memory.
-    	*@sa writeConfig()
-    	*/
+     * This function is useful for restoring the user settings from the config file,
+     * after having modified the settings in memory.
+     * @sa writeConfig()
+     */
     Q_SCRIPTABLE Q_NOREPLY void readConfig();
 
     /**DBUS interface function.  Write current settings to config file.
-    	*This function is useful for storing user settings before modifying them with a DBUS
-    	*script.  The original settings can be restored with readConfig().
-    	*@sa readConfig()
-    	*/
+     * This function is useful for storing user settings before modifying them with a DBUS
+     * script.  The original settings can be restored with readConfig().
+     * @sa readConfig()
+     */
     Q_SCRIPTABLE Q_NOREPLY void writeConfig();
 
     /**DBUS interface function.  Show text message in a popup window.
-    	*@note Not Yet Implemented
-    	*@param x x-coordinate for message window
-    	*@param y y-coordinate for message window
-    	*@param message the text to display in the message window
-    	*/
+     * @note Not Yet Implemented
+     * @param x x-coordinate for message window
+     * @param y y-coordinate for message window
+     * @param message the text to display in the message window
+     */
     Q_SCRIPTABLE Q_NOREPLY void popupMessage( int x, int y, const QString &message );
 
     /**DBUS interface function.  Draw a line on the sky map.
-    	*@note Not Yet Implemented
-    	*@param x1 starting x-coordinate of line
-    	*@param y1 starting y-coordinate of line
-    	*@param x2 ending x-coordinate of line
-    	*@param y2 ending y-coordinate of line
-    	*@param speed speed at which line should appear from start to end points (in pixels per second)
-    	*/
+     * @note Not Yet Implemented
+     * @param x1 starting x-coordinate of line
+     * @param y1 starting y-coordinate of line
+     * @param x2 ending x-coordinate of line
+     * @param y2 ending y-coordinate of line
+     * @param speed speed at which line should appear from start to end points (in pixels per second)
+     */
     Q_SCRIPTABLE Q_NOREPLY void drawLine( int x1, int y1, int x2, int y2, int speed );
 
     /**DBUS interface function.  Set the geographic location.
-    	*@param city the city name of the location
-    	*@param province the province name of the location
-    	*@param country the country name of the location
-    	*/
+     * @param city the city name of the location
+     * @param province the province name of the location
+     * @param country the country name of the location
+     */
     Q_SCRIPTABLE Q_NOREPLY void setGeoLocation( const QString &city, const QString &province, const QString &country );
 
     /**DBUS interface function.  Modify a color.
-    	*@param colorName the name of the color to be modified (e.g., "SkyColor")
-    	*@param value the new color to use
-    	*/
+     * @param colorName the name of the color to be modified (e.g., "SkyColor")
+     * @param value the new color to use
+     */
     Q_SCRIPTABLE Q_NOREPLY void setColor( const QString &colorName, const QString &value );
 
     /**DBUS interface function.  Load a color scheme.
-    	*@param name the name of the color scheme to load (e.g., "Moonless Night")
-    	*/
+     * @param name the name of the color scheme to load (e.g., "Moonless Night")
+     */
     Q_SCRIPTABLE Q_NOREPLY void loadColorScheme( const QString &name );
 
     /**DBUS interface function.  Export the sky image to a file.
-    	*@param filename the filename for the exported image
-    	*@param width the width for the exported image
-    	*@param height the height for the exported image
-    	*/
+     * @param filename the filename for the exported image
+     * @param width the width for the exported image
+     * @param height the height for the exported image
+     */
     Q_SCRIPTABLE Q_NOREPLY void exportImage( const QString &filename, int width, int height );
 
     /**DBUS interface function.  Print the sky image.
-    	*@param usePrintDialog if true, the KDE print dialog will be shown; otherwise, default parameters will be used
-    	*@param useChartColors if true, the "Star Chart" color scheme will be used for the printout, which will save ink.
-    	*/
+     * @param usePrintDialog if true, the KDE print dialog will be shown; otherwise, default parameters will be used
+     * @param useChartColors if true, the "Star Chart" color scheme will be used for the printout, which will save ink.
+     */
     Q_SCRIPTABLE Q_NOREPLY void printImage( bool usePrintDialog, bool useChartColors );
 
     // TODO INDI Scripting to be supported in KDE 4.1
-	#if 0
+    #if 0
     /**DBUS interface function.  Establish an INDI driver.
-    	*@param deviceName The INDI device name
-    	*@param useLocal establish driver locally?
-    	*/
+     * @param deviceName The INDI device name
+     * @param useLocal establish driver locally?
+     */
     Q_SCRIPTABLE Q_NOREPLY void startINDI (const QString &deviceName, bool useLocal);
 
     /**DBUS interface function. Set current device. All subsequent functions will
-    	 communicate with this device until changed.
-    	 *@param deviceName The INDI device name
-    	*/
+     * communicate with this device until changed.
+     * @param deviceName The INDI device name
+     */
     Q_SCRIPTABLE Q_NOREPLY void setINDIDevice (const QString &deviceName);
 
     /**DBUS interface function. Shutdown an INDI driver.
-    	*@param driverName the name of the driver to be shut down
-    	*/
+     * @param driverName the name of the driver to be shut down
+     */
     Q_SCRIPTABLE Q_NOREPLY void shutdownINDI (const QString &driverName);
 
     /**DBUS interface function.  Turn INDI driver on/off.
-    	*@param turnOn if true, turn driver on; otherwise turn off
-    	*/
+     * @param turnOn if true, turn driver on; otherwise turn off
+     */
     Q_SCRIPTABLE Q_NOREPLY void switchINDI(bool turnOn);
 
     /**DBUS interface function.  Set INDI connection port.
-    	*@param port the port identifier
-    	*/
+     * @param port the port identifier
+     */
     Q_SCRIPTABLE Q_NOREPLY void setINDIPort(const QString &port);
 
     /**DBUS interface function.  Set INDI target RA/DEC coordinates
-    	*@param RA the target's Right Ascension coordinate (in Hours) 
-    	*@param DEC the target's Declination coordinate (in Degrees) 
-    	*/
+     * @param RA the target's Right Ascension coordinate (in Hours)
+     * @param DEC the target's Declination coordinate (in Degrees)
+     */
     Q_SCRIPTABLE Q_NOREPLY void setINDITargetCoord(double RA, double DEC);
 
     /**DBUS interface function.  Set INDI target to a named object.
-    	*@param objectName the name of the object to be targeted
-    	*/
+     * @param objectName the name of the object to be targeted
+     */
     Q_SCRIPTABLE Q_NOREPLY void setINDITargetName(const QString &objectName);
 
     /**DBUS interface function.  Set INDI action.
-    	*@param action the action to set
-    	*/
+     * @param action the action to set
+     */
     Q_SCRIPTABLE Q_NOREPLY void setINDIAction(const QString &action);
 
     /**DBUS interface function.  Pause DBUS execution until named INDI action is completed.
-    	*@param action the action which is to be completed before resuming DBUS execution
-    	*/
+     * @param action the action which is to be completed before resuming DBUS execution
+     */
     Q_SCRIPTABLE Q_NOREPLY void waitForINDIAction(const QString &action);
 
     /**DBUS interface function.  Set INDI focus speed.
-    	*@param speed the speed to use
-    	*
-    	* @todo document units for speed
-    	*/
+     * @param speed the speed to use
+     *
+     *  @todo document units for speed
+     */
     Q_SCRIPTABLE Q_NOREPLY void setINDIFocusSpeed(unsigned int speed);
 
     /**DBUS interface function.  Set INDI focus direction and focus.
-    	*@param focusDir 0 = focus in; 1 = focus out
-    	*/
+     * @param focusDir 0 = focus in; 1 = focus out
+     */
     Q_SCRIPTABLE Q_NOREPLY void startINDIFocus(int focusDir);
 
     /**DBUS interface function.  Set INDI geographical information.
-    	*@param longitude the longitude to set, in Degrees
-    	*@param latitude the latitude to set, in Degrees
-    	*/
+     * @param longitude the longitude to set, in Degrees
+     * @param latitude the latitude to set, in Degrees
+     */
     Q_SCRIPTABLE Q_NOREPLY void setINDIGeoLocation(double longitude, double latitude);
 
     /**DBUS interface function.  Sets focus operation timeout.
-    	*@param timeout the timeout interval, in seconds (?)
-    	*/
+     * @param timeout the timeout interval, in seconds (?)
+     */
     Q_SCRIPTABLE Q_NOREPLY void setINDIFocusTimeout(int timeout);
 
     /**DBUS interface function.  Start camera exposure with a timeout.
-    	*@param timeout the exposure time, in seconds (?)
-    	*/
+     * @param timeout the exposure time, in seconds (?)
+     */
     Q_SCRIPTABLE Q_NOREPLY void startINDIExposure(int timeout);
 
     /**DBUS interface function.  Set INDI UTC date and time.
-    	*@param UTCDateTime the UTC date and time (e.g., "23 June 2004 12:30:00" ?)
-    	*/
+     * @param UTCDateTime the UTC date and time (e.g., "23 June 2004 12:30:00" ?)
+     */
     Q_SCRIPTABLE Q_NOREPLY void setINDIUTC(const QString &UTCDateTime);
 
     /**DBUS interface function. Set INDI Telescope action.
-    	*@param action the action to set
-    	*/
+     * @param action the action to set
+     */
     Q_SCRIPTABLE Q_NOREPLY void setINDIScopeAction(const QString &action);
 
     /**DBUS interface function. Set CCD camera frame type.
-    	*@param type the frame type
-    	*/
+     * @param type the frame type
+     */
     Q_SCRIPTABLE Q_NOREPLY void setINDIFrameType(const QString &type);
 
     /**DBUS interface function. Set CCD filter.
-    	*@param filter_num identifier of the CCD filter
-    	*/
+     * @param filter_num identifier of the CCD filter
+     */
     Q_SCRIPTABLE Q_NOREPLY void setINDIFilterNum(int filter_num);
 
     /**DBUS interface function. Set CCD target temperature.
-    	*@param temp the target CCD temperature (in Celsius ?)
-    	*/
+     * @param temp the target CCD temperature (in Celsius ?)
+     */
     Q_SCRIPTABLE Q_NOREPLY void setINDICCDTemp(int temp);
 
-	#endif
+    #endif
 
     /**
-    	*Update time-dependent data and (possibly) repaint the sky map.
-    	*@param automaticDSTchange change DST status automatically?
-    	*/
+     * Update time-dependent data and (possibly) repaint the sky map.
+     * @param automaticDSTchange change DST status automatically?
+     */
     void updateTime( const bool automaticDSTchange = true );
 
-    /**
-    	*Apply new settings and redraw skymap
-    	*/
+    /** Apply new settings and redraw skymap */
     void slotApplyConfigChanges();
 
-    /**
-    	*action slot: Generate toolbars with new user-specified configuration
-    	*/
-    void slotApplyToolbarConfig();
+    /** Called when zoom level is changed. Enables/disables zoom
+     *  actions and updates status bar. */
+    void slotZoomChanged();
 
-    /**
-    	* Zoom in by a given factor
-        *
-    	*/
-    void zoomIn( const double factor );
-
-    /**
-    	* Zoom out by a given factor
-        *
-    	*/
-    void zoomOut( const double factor );
-
-    /**
-    	*action slot: Zoom in one step
-    	*/
-    void slotZoomIn();
-
-
-    /**
-    	*action slot: Zoom out one step
-    	*/
-    void slotZoomOut();
-
-    /**
-    	*action slot: Set the zoom level to its default value
-    	*/
-    void slotDefaultZoom();
-
-    /**
-    	*action slot: Allow user to specify a field-of-view angle for the display window in degrees, 
-    	*and set the zoom level accordingly.
-    	*/
+    /** action slot: Allow user to specify a field-of-view angle for the display window in degrees,
+     * and set the zoom level accordingly. */
     void slotSetZoom();
-    /**
-    	*action slot: Toggle whether kstars is tracking current position
-    	*/
+
+    /** action slot: Toggle whether kstars is tracking current position */
     void slotTrack();
 
-    /**
-    	*action slot: open dialog for selecting a new geographic location
-    	*/
+    /** action slot: open dialog for selecting a new geographic location */
     void slotGeoLocator();
 
     /**Delete FindDialog because ObjNames list has changed in KStarsData due to
-    	*reloading star data. So list in FindDialog must be new filled with current data.
-    	*/
+     * reloading star data. So list in FindDialog must be new filled with current data. */
     void clearCachedFindDialog();
 
-    /**
-    	*Remove all trails which may have been added to solar system bodies
-    	*/
+    /** Remove all trails which may have been added to solar system bodies */
     void slotClearAllTrails();
 
+    /** Display position in the status bar. */
+    void slotShowPositionBar(SkyPoint*);
+
 private slots:
-    /**
-    	*action slot: sync kstars clock to system time
-    	*/
+    /** action slot: sync kstars clock to system time */
     void slotSetTimeToNow();
 
-    /**
-    	*action slot: open a dialog for setting the time and date
-    	*/
+    /** action slot: open a dialog for setting the time and date */
     void slotSetTime();
 
-    /**
-    	*action slot: toggle whether kstars clock is running or not
-    	*/
+    /** action slot: toggle whether kstars clock is running or not */
     void slotToggleTimer();
 
-    /**
-    	*action slot: open dialog for finding a named object
-    	*/
+    /** action slot: open dialog for finding a named object */
     void slotFind();
 
-    /**
-     * action slot: open KStars setup wizard
-     */
+    /** action slot: open KStars setup wizard */
     void slotWizard();
 
-    /**
-     * action slot: open KNewStuff window to download extra data.
-     */
+    /** action slot: open KNewStuff window to download extra data. */
     void slotDownload();
 
-    /**
-     * action slot: open KStars calculator to compute astronomical
-     * ephemeris
-     */
-
+    /** action slot: open KStars calculator to compute astronomical ephemeris */
     void slotCalculator();
 
-    /**
-     * action slot: open KStars AAVSO Light Curve Generator
-     */
-
+    /** action slot: open KStars AAVSO Light Curve Generator */
     void slotLCGenerator();
 
-    /**
-    * action slot: open Elevation vs. Time tool
-    */
-
+    /** action slot: open Elevation vs. Time tool */
     void slotAVT();
 
-    /**
-     * action slot: open What's up tonight dialog
-     */
+    /** action slot: open What's up tonight dialog */
     void slotWUT();
 
-    /**
-     * action slot: open Sky Calendar tool
-     */
+    /** action slot: open Sky Calendar tool */
     void slotCalendar();
 
-    /**
-     * action slot: open the glossary
-     */
+    /** action slot: open the glossary */
     void slotGlossary();
 
-    /**
-     * action slot: open ScriptBuilder dialog
-     */
+    /** action slot: open ScriptBuilder dialog */
     void slotScriptBuilder();
 
-    /**
-     * action slot: open Solar system viewer
-     */
+    /** action slot: open Solar system viewer */
     void slotSolarSystem();
 
-    /**
-     * action slot: open Jupiter Moons tool
-     */
+    /** action slot: open Jupiter Moons tool */
     void slotJMoonTool();
 
-    /**
-     * action slot: open Flag Manager
-     */
+    /** action slot: open Flag Manager */
     void slotFlagManager();
 
-    /**
-     * action slot: open Telescope wizard
-     */
+    /** action slot: open Telescope wizard */
     void slotTelescopeWizard();
 
-    /**
-     * action slot: open Telescope wizard
-     */
+    /** action slot: open Telescope wizard */
     void slotTelescopeProperties();
 
-    /**
-     * action slot: open Image Sequence dialog
-     */
+    /** action slot: open Image Sequence dialog */
     void slotImageSequence();
 
-    /**
-    * action slot: open INDI driver panel
-    */
+    /** action slot: open INDI driver panel */
     void slotINDIDriver();
 
-    /**
-    * action slot: open INDI control panel
-    */
+    /** action slot: open INDI control panel */
     void slotINDIPanel();
 
-    /**
-    	*action slot: open dialog for setting the view options
-    	*/
+    /** action slot: open dialog for setting the view options */
     void slotViewOps();
 
     /** finish setting up after the kstarsData has finished
      */
-    void datainitFinished(bool worked);
-
-    /**Open new KStars window. */
-    void newWindow();
-
-    /**Close KStars window. */
-    void closeWindow();
+    void datainitFinished();
 
     /** Open FITS image. */
     void slotOpenFITS();
@@ -650,16 +538,16 @@ private slots:
     void slotManualFocus();
 
     /**Meta-slot to point the focus at special points (zenith, N, S, E, W).
-    	*Uses the name of the Action which sent the Signal to identify the
-    	*desired direction.  */
+     * Uses the name of the Action which sent the Signal to identify the
+     * desired direction.  */
     void slotPointFocus();
 
     /**Meta-slot to set the color scheme according to the name of the
-    	*Action which sent the activating signal.  */
+     * Action which sent the activating signal.  */
     void slotColorScheme();
 
     /**Select the Target symbol (a.k.a. field-of-view indicator) */
-    void slotTargetSymbol();
+    void slotTargetSymbol(bool flag);
 
     /**Invoke the Field-of-View symbol editor window */
     void slotFOVEdit();
@@ -674,53 +562,42 @@ private slots:
     void slotObsList();
 
     /**Meta-slot to handle display toggles for all of the viewtoolbar buttons.
-    	*uses the name of the sender to identify the item to change.  */
+     * uses the name of the sender to identify the item to change.  */
     void slotViewToolBar();
 
     /**Meta-slot to handle toggling display of GUI elements (toolbars and infoboxes)
-    	*uses name of the sender action to identify the widget to hide/show.  */
+     * uses name of the sender action to identify the widget to hide/show.  */
     void slotShowGUIItem( bool );
 
-    /**Re-assign the input focus to the SkyMap widget.
-    	*/
-    void mapGetsFocus();
-
     /**Toggle to and from full screen mode */
     void slotFullScreen();
 
     /**Save data to config file before exiting.*/
     void slotAboutToQuit();
 
+    void slotEquipmentWriter();
+
+    void slotObserverAdd();
+
+    void slotExecute();
+
 private:
-    /**
-    	*Initialize Menu bar, toolbars and all Actions.
-    	*/
+    /** Load FOV information and repopulate menu. */
+    void repopulateFOV();
+
+    /** Initialize Menu bar, toolbars and all Actions. */
     void initActions();
 
-    /**
-    	*Initialize Field-of-View symbols and FOV submenu
-    	*/
-    void initFOV();
-
-    /**
-    	*Initialize Status bar.
-    	*/
+    /** Initialize Status bar. */
     void initStatusBar();
 
-    /**
-    	*Initialize focus position
-    	*/
+    /** Initialize focus position */
     void initFocus();
 
-    /**
-    	*Build the KStars main window
-    	*/
+    /** Build the KStars main window */
     void buildGUI();
 
-    void reportZoom();
-
     KStarsData *kstarsData;
-    KStarsSplash *splash;
     SkyMap *skymap;
 
     TimeStepBox *TimeStep;
@@ -732,22 +609,24 @@ private:
 
     //FIXME: move to KStarsData
     ObservingList *obsList;
+    EquipmentWriter *eWriter;
+    ObserverAdd *oAdd;
+    Execute *execute;
     AltVsTime *avt;
     WUTDialog *wut;
     SkyCalendar *skycal;
     ScriptBuilder *sb;
     PlanetViewer *pv;
     JMoonTool *jmt;
-    QList<ImageViewer*> m_ImageViewerList;
     FlagManager *fm;
+    AstroCalc *astrocalc;
 
     INDIMenu *indimenu;
     INDIDriver *indidriver;
     imagesequence *indiseq;  /* We need imgsequence here because it runs in batch mode */
 
-    QActionGroup *projectionGroup, *fovGroup, *cschemeGroup;
+    QActionGroup *projectionGroup, *cschemeGroup;
 
-    int idSpinBox;
     bool DialogIsObsolete;
     bool StartClockRunning;
     QString StartDateString;
@@ -759,12 +638,10 @@ private:
     OpsSolarSystem *opsolsys;
     OpsColors *opcolors;
     OpsAdvanced *opadvanced;
-    OpsINDI	*opsindi;
+    OpsINDI *opsindi;
 #ifdef HAVE_XPLANET
     OpsXplanet  *opsxplanet;
 #endif
-
-    KLed *m_DiskLED;
 };
 
 #endif
