@@ -27,7 +27,6 @@
 #include "skyobjects/deepskyobject.h"
 #include "skyobjects/ksplanet.h"
 
-#include "constellationboundary.h"
 #include "constellationboundarylines.h"
 #include "constellationlines.h"
 #include "culturelist.h"
@@ -38,10 +37,7 @@
 #include "equator.h"
 #include "ecliptic.h"
 #include "horizoncomponent.h"
-#include "jupitermoonscomponent.h"
-#include "saturnmoonscomponent.h"
 #include "milkyway.h"
-#include "magellanicclouds.h"
 #include "solarsystemcomposite.h"
 #include "starcomponent.h"
 #include "deepstarcomponent.h"
@@ -50,77 +46,50 @@
 
 #include "skymesh.h"
 #include "skylabeler.h"
-#include "infoboxes.h"
 
-SkyMapComposite::SkyMapComposite(SkyComponent *parent, KStarsData *data) :
+SkyMapComposite::SkyMapComposite(SkyComposite *parent ) :
         SkyComposite(parent), m_reindexNum( J2000 )
 {
     m_skyLabeler = SkyLabeler::Instance();
 
-    m_skyMesh = SkyMesh::Create( data, 3 );  // level 5 mesh = 8192 trixels
-
-    m_skyMesh->debug( 0 );               //  1 => print "indexing ..."
+    m_skyMesh = SkyMesh::Create( 3 );  // level 5 mesh = 8192 trixels
+    m_skyMesh->debug( 0 );
+    //  1 => print "indexing ..."
     //  2 => prints totals too
     // 10 => prints detailed lists
     // You can also set the debug level of individual
     // appendLine() and appendPoly() calls.
+
     //Add all components
-    m_MilkyWay = new MilkyWay( this );
-    addComponent( m_MilkyWay );
-    m_MagellanicClouds = new MagellanicClouds( this );
-    addComponent( m_MagellanicClouds );
     //Stars must come before constellation lines
-    m_Stars = StarComponent::Create( this );
-    addComponent( m_Stars );
-
-    m_CoordinateGrid = new CoordinateGrid( this );
-    addComponent( m_CoordinateGrid );
-
-    m_CBoundLines = new ConstellationBoundaryLines( this );
-    addComponent( m_CBoundLines );
+    addComponent( m_MilkyWay       = new MilkyWay( this ));
+    addComponent( m_Stars          = StarComponent::Create( this ));
+    addComponent( m_CoordinateGrid = new CoordinateGrid( this ));
 
+    // Do add to components.
+    addComponent( m_CBoundLines = new ConstellationBoundaryLines( this ));
     m_Cultures = new CultureList();
-
-    m_CLines = new ConstellationLines( this );
-    addComponent( m_CLines );
-
-    m_CNames = new ConstellationNamesComponent( this );
-    addComponent( m_CNames );
-
-    m_Equator = new Equator( this );
-    addComponent( m_Equator );
-
-    m_Ecliptic = new Ecliptic( this );
-    addComponent( m_Ecliptic );
-
-    m_Horizon = new HorizonComponent( this );
-    addComponent( m_Horizon );
-
-    m_Satellites = new SatelliteComposite( this );
-    addComponent( m_Satellites );
-
-    //m_DeepSky = new DeepSkyComponent( this, &Options::showDeepSky,
-    //		&Options::showMessier, &Options::showNGC, &Options::showIC,
-    //		&Options::showOther, &Options::showMessierImages );
-
-    m_DeepSky = new DeepSkyComponent( this );
-    addComponent( m_DeepSky );
+    addComponent( m_CLines     = new ConstellationLines( this, m_Cultures ));
+    addComponent( m_CNames     = new ConstellationNamesComponent( this, m_Cultures ));
+    addComponent( m_Equator    = new Equator( this ));
+    addComponent( m_Ecliptic   = new Ecliptic( this ));
+    addComponent( m_Horizon    = new HorizonComponent( this ));
+    // Disable satellites for now
+    // addComponent( m_Satellites = new SatelliteComposite( this ));
+    addComponent( m_DeepSky    = new DeepSkyComponent( this ));
 
     m_CustomCatalogs = new SkyComposite( this );
     for ( int i=0; i<Options::catalogFile().size(); ++ i ) {
-        CustomCatalogComponent *cc = new CustomCatalogComponent( this, Options::catalogFile()[i], false, i );
-        cc->init( data );
-        m_CustomCatalogs->addComponent( cc );
+        m_CustomCatalogs->addComponent(
+            new CustomCatalogComponent( this, Options::catalogFile()[i], false, i )
+            );
     }
 
-    m_SolarSystem = new SolarSystemComposite( this, data );
-    addComponent( m_SolarSystem );
-
-    m_Flags = new FlagComponent( this );
-    addComponent( m_Flags );
+    addComponent( m_SolarSystem = new SolarSystemComposite( this ));
+    addComponent( m_Flags       = new FlagComponent( this ));
 
     connect( this, SIGNAL( progressText( const QString & ) ),
-             data, SIGNAL( progressText( const QString & ) ) );
+             KStarsData::Instance(), SIGNAL( progressText( const QString & ) ) );
 }
 
 SkyMapComposite::~SkyMapComposite()
@@ -131,7 +100,7 @@ SkyMapComposite::~SkyMapComposite()
     delete m_Flags;
 }
 
-void SkyMapComposite::update(KStarsData *data, KSNumbers *num )
+void SkyMapComposite::update(KSNumbers *num )
 {
     //printf("updating SkyMapComposite\n");
     //1. Milky Way
@@ -143,7 +112,7 @@ void SkyMapComposite::update(KStarsData *data, KSNumbers *num )
     //4. Constellation lines
     //m_CLines->update( data, num );
     //5. Constellation names
-    m_CNames->update( data, num );
+    m_CNames->update( num );
     //6. Equator
     //m_Equator->update( data, num );
     //7. Ecliptic
@@ -151,27 +120,27 @@ void SkyMapComposite::update(KStarsData *data, KSNumbers *num )
     //8. Deep sky
     //m_DeepSky->update( data, num );
     //9. Custom catalogs
-    m_CustomCatalogs->update( data, num );
+    m_CustomCatalogs->update( num );
     //10. Stars
     //m_Stars->update( data, num );
     //m_CLines->update( data, num );  // MUST follow stars.
 
     //12. Solar system
-    m_SolarSystem->update( data, num );
+    m_SolarSystem->update( num );
     //13. Satellites
     //m_Satellites->update( data, num );
     //14. Horizon
-    m_Horizon->update( data, num );
+    m_Horizon->update( num );
 }
 
-void SkyMapComposite::updatePlanets(KStarsData *data, KSNumbers *num )
+void SkyMapComposite::updatePlanets(KSNumbers *num )
 {
-    m_SolarSystem->updatePlanets( data, num );
+    m_SolarSystem->updatePlanets( num );
 }
 
-void SkyMapComposite::updateMoons(KStarsData *data, KSNumbers *num )
+void SkyMapComposite::updateMoons(KSNumbers *num )
 {
-    m_SolarSystem->updateMoons( data, num );
+    m_SolarSystem->updateMoons( num );
 }
 
 //Reimplement draw function so that we have control over the order of
@@ -200,7 +169,8 @@ void SkyMapComposite::draw( QPainter& psky )
 
     // prepare the aperture
     float radius = map->fov();
-    if ( radius > 90.0 ) radius = 90.0;
+    if ( radius > 90.0 )
+        radius = 90.0;
 
     if ( m_skyMesh->inDraw() ) {
         printf("Warning: aborting concurrent SkyMapComposite::draw()\n");
@@ -212,8 +182,7 @@ void SkyMapComposite::draw( QPainter& psky )
     m_skyMesh->aperture( focus, radius + 1.0, DRAW_BUF ); // divide by 2 for testing
 
     // create the no-precess aperture if needed
-    if ( Options::showGrid() || Options::showCBounds() ||
-            Options::showEquator() ) {
+    if ( Options::showGrid() || Options::showCBounds() || Options::showEquator() ) {
         m_skyMesh->index( focus, radius + 1.0, NO_PRECESS_BUF );
     }
 
@@ -222,12 +191,11 @@ void SkyMapComposite::draw( QPainter& psky )
     m_skyLabeler->useStdFont( psky );
 
     // info boxes have highest label priority
-    map->infoBoxes()->reserveBoxes( psky );
+    // FIXME: REGRESSION. Labeler now know nothing about infoboxes
+    // map->infoBoxes()->reserveBoxes( psky );
 
     m_MilkyWay->draw( psky );
 
-    m_MagellanicClouds->draw( psky );
-
     m_CoordinateGrid->draw( psky );
 
     // Draw constellation boundary lines only if we draw western constellations
@@ -259,6 +227,7 @@ void SkyMapComposite::draw( QPainter& psky )
     m_skyLabeler->drawQueuedLabels( psky );
     m_CNames->draw( psky );
     m_Stars->drawLabels( psky );
+    m_DeepSky->drawLabels( psky );
 
     m_Flags->draw( psky );
 
@@ -292,7 +261,7 @@ SkyObject* SkyMapComposite::objectNearest( SkyPoint *p, double &maxrad ) {
     SkyObject *oTry = 0;
     SkyObject *oBest = 0;
 
-    //printf("%.1f %.1f\n", p->ra()->Degrees(), p->dec()->Degrees() );
+    //printf("%.1f %.1f\n", p->ra().Degrees(), p->dec().Degrees() );
     m_skyMesh->aperture( p, maxrad + 1.0, OBJ_NEAREST_BUF);
 
     oBest = m_Stars->objectNearest( p, rBest );
@@ -369,47 +338,21 @@ bool SkyMapComposite::removeNameLabel( SkyObject *o ) {
     return true;
 }
 
-bool SkyMapComposite::addTrail( SkyObject *o ) {
-    foreach ( SkyComponent *comp, solarSystem() ) {
-      //DEBUG
-      kDebug() << "here" << endl;
-        if ( comp->addTrail( o ) ) return true;
-    }
-    //Did not find object o
-    return false;
-}
-
-bool SkyMapComposite::hasTrail( SkyObject *o, bool &found ) {
-    found = false;
-    foreach ( SkyComponent *comp, solarSystem() ) {
-        if ( comp->hasTrail( o, found ) ) return true;
-        //It's possible we found the object, but it had no trail:
-        if ( found ) return false;
-    }
-    //Did not find object o
-    return false;
-}
-
-bool SkyMapComposite::removeTrail( SkyObject *o ) {
-    foreach ( SkyComponent *comp, solarSystem() ) {
-        if ( comp->removeTrail( o ) ) return true;
-    }
-    //Did not find object o
-    return false;
-}
-
-void SkyMapComposite::clearTrailsExcept( SkyObject *exOb ) {
-    foreach ( SkyComponent *comp, solarSystem() ) {
-        comp->clearTrailsExcept( exOb );
-    }
-}
-
-QHash<int, QStringList>& SkyMapComposite::objectNames() {
+QHash<int, QStringList>& SkyMapComposite::getObjectNames() {
     return m_ObjectNames;
 }
 
-QStringList& SkyMapComposite::objectNames( int type ) {
-    return m_ObjectNames[ type ];
+QList<SkyObject*> SkyMapComposite::findObjectsInArea( const SkyPoint& p1, const SkyPoint& p2 )
+{
+    const SkyRegion& region = m_skyMesh->skyRegion( p1, p2 );
+    QList<SkyObject*> list;
+    // call objectsInArea( QList<SkyObject*>&, const SkyRegion& ) for each of the
+    // components of the SkyMapComposite
+    if( m_Stars->selected() )
+        m_Stars->objectsInArea( list, region );
+    if( m_DeepSky->selected() )
+        m_DeepSky->objectsInArea( list, region );
+    return list;
 }
 
 SkyObject* SkyMapComposite::findByName( const QString &name ) {
@@ -437,16 +380,6 @@ SkyObject* SkyMapComposite::findStarByGenetiveName( const QString name ) {
     return m_Stars->findStarByGenetiveName( name );
 }
 
-/**
-SkyObject* SkyMapComposite::findStarByGenetiveName( const QString &name ) {
-	foreach( SkyObject *s, m_Stars->objectList() ) 
-		if ( s->name2() == name || ((StarObject*)s)->gname(false) == name ) 
-			return (SkyObject*)s;
-
-	return 0;
-}
-**/
-
 KSPlanetBase* SkyMapComposite::planet( int n ) {
     if ( n == KSPlanetBase::SUN ) return (KSPlanetBase*)(m_SolarSystem->findByName( "Sun" ) );
     if ( n == KSPlanetBase::MERCURY ) return (KSPlanetBase*)(m_SolarSystem->findByName( i18n( "Mercury" ) ) );
@@ -462,11 +395,9 @@ KSPlanetBase* SkyMapComposite::planet( int n ) {
 	return 0;
 }
 
-void SkyMapComposite::addCustomCatalog( const QString &filename, KStarsData *data, int index ) {
+void SkyMapComposite::addCustomCatalog( const QString &filename, int index ) {
     CustomCatalogComponent *cc = new CustomCatalogComponent( this, filename, false, index );
-    cc->init( data );
-    
-    if ( cc->objectList().size() ) {
+    if( cc->objectList().size() ) {
         m_CustomCatalogs->addComponent( cc );
     } else {
         delete cc;
@@ -486,32 +417,15 @@ void SkyMapComposite::removeCustomCatalog( const QString &name ) {
     kWarning() << i18n( "Could not find custom catalog component named %1." , name) ;
 }
 
-void SkyMapComposite::reloadDeepSky( KStarsData *data ) {
-    m_DeepSky->clear();
-    m_DeepSky->init( data );
+void SkyMapComposite::reloadCLines( ) {
+    delete m_CLines;
+    m_CLines = new ConstellationLines( this, m_Cultures );
 }
 
-void SkyMapComposite::reloadAsteroids( KStarsData *data ) {
-    m_SolarSystem->reloadAsteroids( data );
-}
-
-void SkyMapComposite::reloadComets( KStarsData *data ) {
-    m_SolarSystem->reloadComets( data );
-}
-
-void SkyMapComposite::reloadCLines( KStarsData *data ) {
-    if( m_CLines ) 
-        delete m_CLines;
-    m_CLines = new ConstellationLines( this );
-    m_CLines->init( data );
-}
-
-void SkyMapComposite::reloadCNames( KStarsData *data ) {
+void SkyMapComposite::reloadCNames( ) {
     objectNames(SkyObject::CONSTELLATION).clear();
-    if( m_CNames )
-        delete m_CNames;
-    m_CNames = new ConstellationNamesComponent( this );
-    m_CNames->init( data );
+    delete m_CNames;
+    m_CNames = new ConstellationNamesComponent( this, m_Cultures );
 }
 
 bool SkyMapComposite::isLocalCNames() {
@@ -524,41 +438,25 @@ void SkyMapComposite::emitProgressText( const QString &message ) {
     //kDebug() << QString("PROGRESS TEXT: %1\n").arg( message );
 }
 
-float SkyMapComposite::faintStarMagnitude() const {
-    return m_Stars->faintMagnitude();
-}
-
-int SkyMapComposite::starColorMode() const {
-    return m_Stars->starColorMode();
-}
-
-int SkyMapComposite::starColorIntensity() const {
-    return m_Stars->starColorIntensity();
-}
-
-QList<DeepSkyObject*>& SkyMapComposite::deepSkyObjects() {
+const QList<DeepSkyObject*>& SkyMapComposite::deepSkyObjects() const {
     return m_DeepSky->objectList();
 }
 
-QList<SkyComponent*> SkyMapComposite::solarSystem() {
-    return m_SolarSystem->components();
-}
-
-QList<SkyObject*>& SkyMapComposite::constellationNames() {
+const QList<SkyObject*>& SkyMapComposite::constellationNames() const {
     return m_CNames->objectList();
 }
 
 // Returns only named stars, and should not be used
-QList<SkyObject*>& SkyMapComposite::stars() {
+const QList<SkyObject*>& SkyMapComposite::stars() const {
     return m_Stars->objectList();
 }
 
 
-QList<SkyObject*>& SkyMapComposite::asteroids() {
+const QList<SkyObject*>& SkyMapComposite::asteroids() const {
     return m_SolarSystem->asteroids();
 }
 
-QList<SkyObject*>& SkyMapComposite::comets() {
+const QList<SkyObject*>& SkyMapComposite::comets() const {
     return m_SolarSystem->comets();
 }
 
