@@ -21,11 +21,6 @@
 #include <QTimer>
 #include <QWidget>
 #include <QPixmap>
-#include <QMouseEvent>
-#include <QWheelEvent>
-#include <QKeyEvent>
-#include <QResizeEvent>
-#include <QPaintEvent>
 
 #include "skyobjects/skypoint.h"
 #include "skyobjects/skyline.h"
@@ -36,18 +31,17 @@
 
 class QPainter;
 class QPaintDevice;
-class QPoint;
 class QPixmap;
+
 //DEBUG_KIO_JOB
 class KJob;
 
 class dms;
-class InfoBoxes;
-class KStars;
 class KStarsData;
-class KSPlanetBase;
 class KSPopupMenu;
 class SkyObject;
+class InfoBoxWidget;
+class InfoBoxes;
 
 /**@class SkyMap
 	*
@@ -74,20 +68,14 @@ protected:
     */
     explicit SkyMap();
 
-    SkyMap( SkyMap& skyMap );
-
 public:
-
     static SkyMap* Create();
 
     static SkyMap* Instance();
 
     static bool IsSlewing() { return pinstance->isSlewing(); }
 
-
-    /**
-    *Destructor (empty)
-    */
+    /** Destructor (empty) */
     ~SkyMap();
 
     enum Projection { Lambert=0, AzimuthalEquidistant=1,
@@ -101,18 +89,10 @@ public:
     	*/
     float fov();
 
+    /**@short Update object name and coordinates in the Focus InfoBox */
+    void showFocusCoords();
 
-    /**
-    	*@return pointer to InfoBoxes object.
-    	*/
-    InfoBoxes* infoBoxes() const { return IBoxes; }
-
-    /**@short Update object name and coordinates in the Focus InfoBox
-    	*/
-    void showFocusCoords( bool coordsOnly = false );
-
-    /**@short Update the focus position according to current options.
-    	*/
+    /**@short Update the focus position according to current options. */
     void updateFocus();
 
     /**@short Retrieve the Focus point; the position on the sky at the
@@ -141,15 +121,6 @@ public:
     	*/
     SkyPoint* focusPoint() { return &FocusPoint; }
 
-    /**@short retrieve the last focus posiiton.
-    	*
-    	*We store the previous focus point to determine how much the focus 
-    	*position has changed.  
-    	*
-    	*@return a pointer to the previous central focus point of the sky map
-    	*/
-    SkyPoint* oldfocus() { return &OldFocus; }
-
     /**@short sets the central focus point of the sky map.
     	*@param f a pointer to the SkyPoint the map should be centered on
     	*/
@@ -236,15 +207,10 @@ public:
     	*/
     void setDestinationAltAz(double alt, double az);
 
-    /**@short set the previous central focus point of the sky map.
-    	*@param f a pointer to the SkyPoint the map was centered on
-    	*/
-    void setOldFocus( SkyPoint *f ) { OldFocus.set( f->ra(), f->dec() ); }
-
     /**@short set the FocusPoint; the position that is to be the next Destination.
     	*@param f a pointer to the FocusPoint SkyPoint.
     	*/
-    void setFocusPoint( SkyPoint *f ) { if ( f ) FocusPoint.set( f->ra(), f->dec() ); }
+    void setFocusPoint( SkyPoint *f ) { if ( f ) FocusPoint = *f; }
 
     /**@short Retrieve the ClickedPoint position.
     	*
@@ -260,17 +226,6 @@ public:
     	*/
     void setClickedPoint( SkyPoint *f );
 
-    /**@short Retrieve the PreviousClickedPoint position.
-    	*@return a pointer to PreviousClickedPoint, the sky coordinates of the 
-    	*penultimate mouse click.
-    	*/
-    SkyPoint* previousClickedPoint() { return &PreviousClickedPoint; }
-
-    /**Sets the PreviousClickedPoint to the skypoint given as an argument.
-    	*@param f pointer to the new PreviousClickedPoint.
-    	*/
-    void setPreviousClickedPoint( SkyPoint *f ) { PreviousClickedPoint.set( f->ra(), f->dec() ); }
-
     /**@short Retrieve a pointer to MousePoint, the sky coordinates of the mouse cursor.
     	*
     	*When the user moves the mouse in the sky map, the sky coordinates of the mouse
@@ -285,7 +240,7 @@ public:
     	*argument, and this function returns by value.
     	*@param f the new MousePoint (typically the output of dXdYToRaDec()).
     	*/
-    void setMousePoint( SkyPoint f ) { MousePoint.set( f.ra(), f.dec() ); }
+    void setMousePoint( SkyPoint f ) { MousePoint = f; }
 
     /**@short Retrieve the object nearest to a mouse click event.
     	*
@@ -294,7 +249,7 @@ public:
     	*or NULL if there is no CLickedObject.
     	*@return a pointer to the object nearest to a user mouse click.
     	*/
-    SkyObject* clickedObject( void ) const { return ClickedObject; }
+    SkyObject* clickedObject() const { return ClickedObject; }
 
     /**@short Set the ClickedObject pointer to the argument.
     	*@param o pointer to the SkyObject to be assigned as the ClickedObject
@@ -309,7 +264,7 @@ public:
     	*FocusObject, or NULL if there is not FocusObject.
     	*@return a pointer to the object at the center of the sky map.
     	*/
-    SkyObject* focusObject( void ) const { return FocusObject; }
+    SkyObject* focusObject() const { return FocusObject; }
 
     /**@short Set the FocusObject pointer to the argument.
     	*@param o pointer to the SkyObject to be assigned as the FocusObject
@@ -324,7 +279,7 @@ public:
     	*@return pointer to the SkyObject nearest to the mouse hover position.
     	*@see SkyMap::slotTransientLabel()
     	*/
-    SkyObject* transientObject( void ) const { return TransientObject; }
+    SkyObject* transientObject() const { return TransientObject; }
 
     /**@short Set the TransientObject pointer to the argument.
     	*@param o pointer to the SkyObject to be assigned as the TransientObject.
@@ -340,17 +295,13 @@ public:
     	*The variables set by setMapGeometry are:
     	*@li isPoleVisible true if a coordinate Pole is on-screen
     	*@li XMax the horizontal center-to-edge angular distance
-    	*@li guideXMax a version of XMax used for guide lines (same as XMax at low zoom; 2x XMAX otherwise)
-    	*@li guideFOV similar to guideXMax, but for the vertical direction.
     	*@see SkyMap::checkVisibility()
     	*@see SkyMap::paintEvent()
     	*/
-    void setMapGeometry( void );
+    void setMapGeometry();
 
-    float guideMaxLength() const { return m_Guidemax; }
-
-    /**@short Call keyPressEvent, as if the key given as an argument had been pressed. */
-    void invokeKey( int key );
+    /** Set zoom factor. */
+    void setZoomFactor(double factor);
 
     /**@return true if the angular distance measuring mode is on
      */
@@ -389,274 +340,251 @@ public:
      * between *p1 and *p2 that just clips.
      */
     QPointF clipLine( SkyPoint *p1, SkyPoint *p2 );
-
     QPoint clipLineI( SkyPoint *p1, SkyPoint *p2 );
 
     /**Given the coordinates of the SkyPoint argument, determine the
-    	*pixel coordinates in the SkyMap.
-    	*@return QPoint containing screen pixel x, y coordinates of SkyPoint.
-    	*@param o pointer to the SkyPoint for which to calculate x, y coordinates.
-    	*@param useRefraction true = use Options::useRefraction() value.  
-    	*false = do not use refraction.  This argument is only needed 
-    	*for the Horizon, which should never be refracted.
-    	*@param onVisibleHemisphere pointer to a bool to indicate whether the point is
-        * on the visible part of the Celestial Sphere.
-    	*/
+     * pixel coordinates in the SkyMap.
+     * @return QPoint containing screen pixel x, y coordinates of SkyPoint.
+     * @param o pointer to the SkyPoint for which to calculate x, y coordinates.
+     * @param useRefraction true = use Options::useRefraction() value.  
+     *   false = do not use refraction.  This argument is only needed 
+     *   for the Horizon, which should never be refracted.
+     * @param onVisibleHemisphere pointer to a bool to indicate whether the point is
+     *   on the visible part of the Celestial Sphere.
+     */
     QPointF toScreen( SkyPoint *o, bool useRefraction=true, bool *onVisibleHemisphere=NULL);
-    QPointF toScreenQuaternion( SkyPoint *o );
 
-    QPoint toScreenI( SkyPoint *o, bool useRefraction=true, bool *onVisibleHemisphere=NULL);
-
-    /**
-    	*@return the given SkyLine, transformed to screen pixel coordinates.
-    	*If only a portion of the line is on-screen, this function returns 
-    	*the on-screen segment.  If no portion of the line is on-screen, 
-    	*a null line is returned.
-    	*
-    	*@param o pointer to the SkyLine which is to be transformed to screen coordinates
-    	*@param useRefraction if true, refract according to the user option UseRefraction; 
-    	*if false, do not use refraction regardless of user option
-    	*@param doClipLines if true, lines will be truncated at the screen edge
-    	*/
-    QList<QPointF> toScreen( SkyLine *o, bool useRefraction=true, bool doClipLines=true );
-
-    /**
-        *@return the current scale factor for drawing the map.
-        *@note the scale factor should be 1.0 unless we are printing.
-        */
+    /**@return the current scale factor for drawing the map.
+     * @note the scale factor should be 1.0 unless we are printing.
+     */
     inline double scale() { return m_Scale; }
 
-    /**
-        *@return the bounding rectangle of the skymap, scaled by the current scale factor
-        */
+    /** @return the bounding rectangle of the skymap, scaled by the current scale factor */
     QRect scaledRect();
 
-    /**
-        *@return whether the given QPoint is on the SkyMap.
-        */
-    bool onScreen( QPoint &point );
-    /**
-        *@return whether the given QPointF is on the SkyMap.
-        */
+    /** @return whether the given QPoint is on the SkyMap. */
+    bool onScreen(const QPoint &point );
+    /** @return whether the given QPointF is on the SkyMap. */
+    bool onScreen(const QPointF &pointF );
 
-    bool onScreen( QPointF &pointF );
+    /** @return true if the line connecting the two points is possibly on screen.
+     * will return some false postives. */
+    bool onScreen(const QPointF &p1, const QPointF &p2 );
+    bool onScreen(const QPoint &p1, const QPoint &p2 );
 
-    /**
-       *@return true if the line connecting the two points is possibly on screen.
-       * will return some false postives.
-       */
-    bool onScreen( QPointF &p1, QPointF &p2 );
-    bool onScreen( QPoint &p1, QPoint &p2 );
-
-    void onscreenLine( QPointF &p1, QPointF &p2 );
-    bool onscreenLine2( QPointF &p1, QPointF &p2 );
+    bool onscreenLine( QPointF &p1, QPointF &p2 );
 
     /**@short Determine RA, Dec coordinates of the pixel at (dx, dy), which are the
-    	*screen pixel coordinate offsets from the center of the Sky pixmap.
-    	*@param the screen pixel position to convert
-    	*@param LST pointer to the local sidereal time, as a dms object.
-    	*@param lat pointer to the current geographic laitude, as a dms object
-    	*/
+     * screen pixel coordinate offsets from the center of the Sky pixmap.
+     * @param the screen pixel position to convert
+     * @param LST pointer to the local sidereal time, as a dms object.
+     * @param lat pointer to the current geographic laitude, as a dms object
+     */
     SkyPoint fromScreen( const QPointF &p, dms *LST, const dms *lat );
 
     /**@short Determine if the skypoint p is likely to be visible in the display
-    	*window.
-    	*
-    	*checkVisibility() is an optimization function.  It determines whether an object
-    	*appears within the bounds of the skymap window, and therefore should be drawn.
-    	*The idea is to save time by skipping objects which are off-screen, so it is 
-    	*absolutely essential that checkVisibility() is significantly faster than
-    	*the computations required to draw the object to the screen.
-    	*
-    	*The function first checks the difference between the Declination/Altitude
-    	*coordinate of the Focus position, and that of the point p.  If the absolute 
-    	*value of this difference is larger than fov, then the function returns false.
-    	*For most configurations of the sky map window, this simple check is enough to 
-    	*exclude a large number of objects.
-    	*
-    	*Next, it determines if one of the poles of the current Coordinate System 
-    	*(Equatorial or Horizontal) is currently inside the sky map window.  This is
-    	*stored in the member variable 'bool SkyMap::isPoleVisible, and is set by the 
-    	*function SkyMap::setMapGeometry(), which is called by SkyMap::paintEvent().
-    	*If a Pole is visible, then it will return true immediately.  The idea is that
-    	*when a pole is on-screen it is computationally expensive to determine whether 
-    	*a particular position is on-screen or not: for many valid Dec/Alt values, *all* 
-    	*values of RA/Az will indeed be onscreen, but for other valid Dec/Alt values, 
-    	*only *most* RA/Az values are onscreen.  It is cheaper to simply accept all 
-    	*"horizontal" RA/Az values, since we have already determined that they are 
-    	*on-screen in the "vertical" Dec/Alt coordinate.
-    	*
-    	*Finally, if no Pole is onscreen, it checks the difference between the Focus 
-    	*position's RA/Az coordinate and that of the point p.  If the absolute value of 
-    	*this difference is larger than XMax, the function returns false.  Otherwise,
-    	*it returns true.
-    	
-    	*@param p pointer to the skypoint to be checked.
-    	*@return true if the point p was found to be inside the Sky map window.
-    	*@see SkyMap::setMapGeometry()
-    	*@see SkyMap::fov()
-    	*/
+     * window.
+     * 
+     * checkVisibility() is an optimization function.  It determines whether an object
+     * appears within the bounds of the skymap window, and therefore should be drawn.
+     * The idea is to save time by skipping objects which are off-screen, so it is 
+     * absolutely essential that checkVisibility() is significantly faster than
+     * the computations required to draw the object to the screen.
+     * 
+     * The function first checks the difference between the Declination/Altitude
+     * coordinate of the Focus position, and that of the point p.  If the absolute 
+     * value of this difference is larger than fov, then the function returns false.
+     * For most configurations of the sky map window, this simple check is enough to 
+     * exclude a large number of objects.
+     * 
+     * Next, it determines if one of the poles of the current Coordinate System 
+     * (Equatorial or Horizontal) is currently inside the sky map window.  This is
+     * stored in the member variable 'bool SkyMap::isPoleVisible, and is set by the 
+     * function SkyMap::setMapGeometry(), which is called by SkyMap::paintEvent().
+     * If a Pole is visible, then it will return true immediately.  The idea is that
+     * when a pole is on-screen it is computationally expensive to determine whether 
+     * a particular position is on-screen or not: for many valid Dec/Alt values, *all* 
+     * values of RA/Az will indeed be onscreen, but for other valid Dec/Alt values, 
+     * only *most* RA/Az values are onscreen.  It is cheaper to simply accept all 
+     * "horizontal" RA/Az values, since we have already determined that they are 
+     * on-screen in the "vertical" Dec/Alt coordinate.
+     * 
+     * Finally, if no Pole is onscreen, it checks the difference between the Focus 
+     * position's RA/Az coordinate and that of the point p.  If the absolute value of 
+     * this difference is larger than XMax, the function returns false.  Otherwise,
+     * it returns true.
+     *     
+     * @param p pointer to the skypoint to be checked.
+     * @return true if the point p was found to be inside the Sky map window.
+     * @see SkyMap::setMapGeometry()
+     * @see SkyMap::fov()
+     */
     bool checkVisibility( SkyPoint *p );
 
-    bool checkVisibility( SkyLine *l );
-
     /**Determine the on-screen position angle of a SkyObject.  This is the sum
-    	*of the object's sky position angle (w.r.t. North), and the position angle
-    	*of "North" at the position of the object (w.r.t. the screen Y-axis).  
-    	*The latter is determined by constructing a test point with the same RA but 
-    	*a slightly increased Dec as the object, and calculating the angle w.r.t. the 
-    	*Y-axis of the line connecing the object to its test point. 
-    	*/
+     * of the object's sky position angle (w.r.t. North), and the position angle
+     * of "North" at the position of the object (w.r.t. the screen Y-axis).  
+     * The latter is determined by constructing a test point with the same RA but 
+     * a slightly increased Dec as the object, and calculating the angle w.r.t. the 
+     * Y-axis of the line connecing the object to its test point. 
+     */
     double findPA( SkyObject *o, float x, float y );
 
     /**@short Draw "user labels".  User labels are name labels attached to objects manually with
-    	*the right-click popup menu.  Also adds a label to the FocusObject if the Option UseAutoLabel
-    	*is true.
-    	*@param labelObjects QList of pointers to the objects which need labels (excluding the centered object)
-    	*@param psky painter for the sky
-    	*@note the labelObjects list is managed by the SkyMapComponents class
-    	*/
+     * the right-click popup menu.  Also adds a label to the FocusObject if the Option UseAutoLabel
+     * is true.
+     * @param labelObjects QList of pointers to the objects which need labels (excluding the centered object)
+     * @param psky painter for the sky
+     * @note the labelObjects list is managed by the SkyMapComponents class
+     */
     void drawObjectLabels( QList<SkyObject*>& labelObjects, QPainter &psky );
 
 public slots:
     //DEBUG_KIO_JOB
     void slotJobResult( KJob *j );
 
-    /**@short This overloaded function is used internally to resize the Sky pixmap to match the window size.
-    	*/
+    /**@short This overloaded function is used internally to resize the Sky pixmap to match the window size. */
     virtual void setGeometry( int x, int y, int w, int h );
 
     /**@short This overloaded function is used internally to resize the Sky pixmap to match the window size.
-    	*
-    	*This function behaves essentially like the above function.  It differs only in the data types 	*of its arguments.
-    	*/
+     * This function behaves essentially like the above function.  It differs only in the data types 	*of its arguments.
+     */
     virtual void setGeometry( const QRect &r );
 
     /**Recalculates the positions of objects in the sky, and then repaints the sky map.
-    	*If the positions don't need to be recalculated, use update() instead of forceUpdate().
-    	*This saves a lot of CPU time.
-    	*@param now if true, paintEvent() is run immediately.  Otherwise, it is added to the event queue
-    	*/
+     * If the positions don't need to be recalculated, use update() instead of forceUpdate().
+     * This saves a lot of CPU time.
+     * @param now if true, paintEvent() is run immediately.  Otherwise, it is added to the event queue
+     */
     void forceUpdate( bool now=false );
 
     /**@short Convenience function; simply calls forceUpdate(true).
-    	*@see forceUpdate()
-    	*/
+     * @see forceUpdate()
+     */
     void forceUpdateNow() { forceUpdate( true ); }
 
     /**Estimate the effect of atmospheric refraction on object positions.  Refraction
-    	*affects only the Altitude angle of objects.  Also, the correction should not be applied 
-    	*to the horizon, which is not beyond the atmosphere.
-    	*
-    	*To estimate refraction, we use a simple analytic equation.  To save time, we store
-    	*values of the correction for 0.5-degree Altitude intervals.  Individual objects are then 
-    	*simply assigned the nearest stored value.  The precaclulated values are stored in the 
-    	*RefractCorr1 and RefractCorr2 arrays, and these are initialized in the SkyMap constructor.
-    	*
-    	*There are two cases:  the true altitude is known, and the apparent altitude is needed;
-    	*or the apparent altitude is known and the true altitude is needed.
-    	*@param alt The input altitude
-    	*@param findApparent if true, then alt is the true altitude, and we'll find the apparent alt.
-    	*@return the corrected altitude, as a dms object.
-    	*/
-    dms refract( const dms *alt, bool findApparent );
+     * affects only the Altitude angle of objects.  Also, the correction should not be applied 
+     * to the horizon, which is not beyond the atmosphere.
+     * 
+     * To estimate refraction, we use a simple analytic equation.  To save time, we store
+     * values of the correction for 0.5-degree Altitude intervals.  Individual objects are then 
+     * simply assigned the nearest stored value.  The precaclulated values are stored in the 
+     * RefractCorr1 and RefractCorr2 arrays, and these are initialized in the SkyMap constructor.
+     * 
+     * There are two cases:  the true altitude is known, and the apparent altitude is needed;
+     * or the apparent altitude is known and the true altitude is needed.
+     * @param alt The input altitude
+     * @param findApparent if true, then alt is the true altitude, and we'll find the apparent alt.
+     * @return the corrected altitude, as a dms object.
+     */
+    // FIXME: move out of SkyMap
+    static dms refract( const dms& alt, bool findApparent );
+
+    /** Toggle visibility of geo infobox */
+    void slotToggleGeoBox(bool);
+
+    /** Toggle visibility of focus infobox */
+    void slotToggleFocusBox(bool);
+
+    /** Toggle visibility of time infobox */
+    void slotToggleTimeBox(bool);
+
+    /** Toggle visibility of all infoboxes */
+    void slotToggleInfoboxes(bool);
 
     /**Step the Focus point toward the Destination point.  Do this iteratively, redrawing the Sky
-    	*Map after each step, until the Focus point is within 1 step of the Destination point.
-    	*For the final step, snap directly to Destination, and redraw the map.
-    	*/
-    void slewFocus( void );
+     * Map after each step, until the Focus point is within 1 step of the Destination point.
+     * For the final step, snap directly to Destination, and redraw the map.
+     */
+    void slewFocus();
 
     /**@short Center the display at the point ClickedPoint.
-    	*
-    	*The essential part of the function is to simply set the Destination point, which will emit 
-    	*the destinationChanged() SIGNAL, which triggers the slewFocus() SLOT.  Additionally, this
-    	*function performs some bookkeeping tasks, such updating whether we are tracking the new 
-    	*object/position, adding a Planet Trail if required, etc.
-    	*
-    	*@see destinationChanged()
-    	*@see slewFocus()
-    	*/
-    void slotCenter( void );
-
-    //QUATERNION
-    void slotRotateTo( SkyPoint *p );
+     * 
+     * The essential part of the function is to simply set the Destination point, which will emit 
+     * the destinationChanged() SIGNAL, which triggers the slewFocus() SLOT.  Additionally, this
+     * function performs some bookkeeping tasks, such updating whether we are tracking the new 
+     * object/position, adding a Planet Trail if required, etc.
+     * 
+     * @see destinationChanged()
+     * @see slewFocus()
+     */
+    void slotCenter();
 
     /**@short Popup menu function: Display 1st-Generation DSS image with the Image Viewer.
-    	*@note the URL is generated using the coordinates of ClickedPoint.
-    	*/
+     * @note the URL is generated using the coordinates of ClickedPoint.
+     */
     void slotDSS();
 
     /**@short Popup menu function: Display Sloan Digital Sky Survey image with the Image Viewer.
-    	*@note the URL is generated using the coordinates of ClickedPoint.
-    	*/
-		void slotSDSS();
+     * @note the URL is generated using the coordinates of ClickedPoint.
+     */
+    void slotSDSS();
 
     /**@short Popup menu function: Show webpage about ClickedObject
-    	*(only available for some objects). 
-    	*/
+     * (only available for some objects). 
+     */
     void slotInfo();
 
     /**@short Popup menu function: Show image of ClickedObject
-    	*(only available for some objects). 
-    	*/
+     * (only available for some objects). 
+     */
     void slotImage();
 
-    /**@short Popup menu function: Show the Detailed Information window for ClickedObject.
-    	*/
-    void slotDetail( void );
+    /**@short Popup menu function: Show the Detailed Information window for ClickedObject. */
+    void slotDetail();
 
     /**Add ClickedObject to KStarsData::ObjLabelList, which stores pointers to SkyObjects which
-    	*have User Labels attached.
-    	*/
-    void slotAddObjectLabel( void );
+     * have User Labels attached.
+     */
+    void slotAddObjectLabel();
 
     /**Remove ClickedObject from KStarsData::ObjLabelList, which stores pointers to SkyObjects which
-    	*have User Labels attached.
-    	*/
-    void slotRemoveObjectLabel( void );
+     * have User Labels attached.
+     */
+    void slotRemoveObjectLabel();
 
     /**@short Add a Planet Trail to ClickedObject.
-    	*@note Trails are added simply by calling KSPlanetBase::addToTrail() to add the first point.
-    	*as long as the trail is not empty, new points will be automatically appended to it.
-    	*@note if ClickedObject is not a Solar System body, this function does nothing.
-    	*@see KSPlanetBase::addToTrail()
-    	*/
-    void slotAddPlanetTrail( void );
+     * @note Trails are added simply by calling KSPlanetBase::addToTrail() to add the first point.
+     * as long as the trail is not empty, new points will be automatically appended to it.
+     * @note if ClickedObject is not a Solar System body, this function does nothing.
+     * @see KSPlanetBase::addToTrail()
+     */
+    void slotAddPlanetTrail();
 
     /**@short Remove the PlanetTrail from ClickedObject.
-    	*@note The Trail is removed by simply calling KSPlanetBase::clearTrail().  As long as
-    	*the trail is empty, no new points will be automatically appended.
-    	*@see KSPlanetBase::clearTrail()
-    	*/
-    void slotRemovePlanetTrail( void );
+     * @note The Trail is removed by simply calling KSPlanetBase::clearTrail().  As long as
+     * the trail is empty, no new points will be automatically appended.
+     * @see KSPlanetBase::clearTrail()
+     */
+    void slotRemovePlanetTrail();
 
     /**Popup menu function: Add a custom Image or Information URL.
-    	*Opens the AddLinkDialog window.
-    	*/
-    void addLink( void );
+     * Opens the AddLinkDialog window.
+     */
+    void addLink();
 
     /**Checks whether the timestep exceeds a threshold value.  If so, sets
-    	*ClockSlewing=true and sets the SimClock to ManualMode. 
-    	*/
+     * ClockSlewing=true and sets the SimClock to ManualMode. 
+     */
     void slotClockSlewing();
 
     /**Enables the angular distance measuring mode. It saves the first
-    	*position of the ruler in a SkyPoint. It makes difference between
-    	*having clicked on the skymap and not having done so */
-    void slotBeginAngularDistance(void);
+     * position of the ruler in a SkyPoint. It makes difference between
+     * having clicked on the skymap and not having done so */
+    void slotBeginAngularDistance();
 
     /**Computes the angular distance, prints the result in the status
-    	*bar and disables the angular distance measuring mode
-    	*If the user has clicked on the map the status bar shows the 
-    	*name of the clicked object plus the angular distance. If 
-    	*the user did not clicked on the map, just pressed ], only 
-    	*the angular distance is printed */
-    void slotEndAngularDistance(void);
+     * bar and disables the angular distance measuring mode
+     * If the user has clicked on the map the status bar shows the 
+     * name of the clicked object plus the angular distance. If 
+     * the user did not clicked on the map, just pressed ], only 
+     * the angular distance is printed */
+    void slotEndAngularDistance();
 
     /**Disables the angular distance measuring mode. Nothing is printed
-    	*in the status bar */
-    void slotCancelAngularDistance(void);
+     * in the status bar */
+    void slotCancelAngularDistance();
 
 #ifdef HAVE_XPLANET
     /**Run Xplanet to print a view on the screen*/
@@ -666,50 +594,69 @@ public slots:
     void slotXplanetToFile();
 #endif
 
+    /** Zoom in one step. */
+    void slotZoomIn();
+
+    /** Zoom out one step. */
+    void slotZoomOut();
+
+    /** Set default zoom. */
+    void slotZoomDefault();
+
 signals:
     /**Emitted by setDestination(), and connected to slewFocus().  Whenever the Destination
-    	*point is changed, slewFocus() will iteratively step the Focus toward Destination 
-    	*until it is reached.
-    	*@see SkyMap::setDestination()
-    	*@see SkyMap::slewFocus()
-    	*/
+     * point is changed, slewFocus() will iteratively step the Focus toward Destination 
+     * until it is reached.
+     * @see SkyMap::setDestination()
+     * @see SkyMap::slewFocus()
+     */
     void destinationChanged();
 
     /**Emitted by SkyMap::addLink().  This Signal is used to inform the Details Dialog
-    	*that it needs to update its lists of URL links.
-    	*/
+     * that it needs to update its lists of URL links.
+     */
     void linkAdded();
 
+    /** Emitted when zoom level is changed. */
+    void zoomChanged();
+
+    /** Emitted when current object changed. */
+    void objectChanged(SkyObject*);
+
+    /** Emitted when pointing changed. (At least should) */
+    void positionChanged(SkyPoint*);
+
+    /** Emitted when position under mouse changed. */
+    void mousePointChanged(SkyPoint*);
+
 protected:
     /**Draw the Sky, and all objects in it. */
     virtual void paintEvent( QPaintEvent *e );
 
     /**Process keystrokes:
-    	*@li arrow keys  Slew the map
-    	*@li +/- keys  Zoom in and out 
-    	*@li N/E/S/W keys  Go to the cardinal points on the Horizon
-    	*@li Z  Go to the Zenith
-    	*@li <i>Space</i>  Toggle between Horizontal and Equatorial coordinate systems
-    	*@li 0-9  Go to a major Solar System body (0=Sun; 1-9 are the major planets, except 3=Moon)
-    	*@li [  Place starting point for measuring an angular distance
-    	*@li ]  End point for Angular Distance; display measurement.
-    	*@li <i>Escape</i>  Cancel Angular measurement
-    	*@li ,/<  Step backward one time step
-    	*@li ./>  Step forward one time step
-    	*/
+     * @li arrow keys  Slew the map
+     * @li +/- keys  Zoom in and out
+     * @li <i>Space</i>  Toggle between Horizontal and Equatorial coordinate systems
+     * @li 0-9  Go to a major Solar System body (0=Sun; 1-9 are the major planets, except 3=Moon)
+     * @li [  Place starting point for measuring an angular distance
+     * @li ]  End point for Angular Distance; display measurement.
+     * @li <i>Escape</i>  Cancel Angular measurement
+     * @li ,/<  Step backward one time step
+     * @li ./>  Step forward one time step
+     */
     virtual void keyPressEvent( QKeyEvent *e );
 
     /**When keyRelease is triggered, just set the "slewing" flag to false,
-    	*and update the display (to draw objects that are hidden when slewing==true). */
+     * and update the display (to draw objects that are hidden when slewing==true). */
     virtual void keyReleaseEvent( QKeyEvent *e );
 
     /**Determine RA, Dec coordinates of clicked location.  Find the SkyObject
-    	*which is nearest to the clicked location.
-    	*
-    	*If left-clicked: Set set mouseButtonDown==true, slewing==true; display 
-    	*nearest object name in status bar.
-    	*If right-clicked: display popup menu appropriate for nearest object.
-    	*/
+     * which is nearest to the clicked location.
+     *
+     * If left-clicked: Set set mouseButtonDown==true, slewing==true; display
+     * nearest object name in status bar.
+     * If right-clicked: display popup menu appropriate for nearest object.
+     */
     virtual void mousePressEvent( QMouseEvent *e );
 
     /**set mouseButtonDown==false, slewing==false */
@@ -719,24 +666,22 @@ protected:
     virtual void mouseDoubleClickEvent( QMouseEvent *e );
 
     /**This function does several different things depending on the state of the program:
-    	*@li If Angle-measurement mode is active, update the end-ruler point to the mouse cursor,
-    	*and continue this function.
-    	*@li If we are dragging an InfoBox, simply redraw the screen and return.
-    	*@li If we are defining a ZoomBox, update the ZoomBox rectangle, redraw the screen, 
-    	*and return.
-    	*@li If dragging the mouse in the map, update focus such that RA, Dec under the mouse 
-    	*cursor remains constant. 
-    	*@li If just moving the mouse, simply update the curso coordinates in the status bar.
-    	*/
+     * @li If Angle-measurement mode is active, update the end-ruler point to the mouse cursor,
+     *     and continue this function.
+     * @li If we are defining a ZoomBox, update the ZoomBox rectangle, redraw the screen,
+     *     and return.
+     * @li If dragging the mouse in the map, update focus such that RA, Dec under the mouse
+     *     cursor remains constant.
+     * @li If just moving the mouse, simply update the curso coordinates in the status bar.
+     */
     virtual void mouseMoveEvent( QMouseEvent *e );
 
     /**Zoom in and out with the mouse wheel. */
     virtual void wheelEvent( QWheelEvent *e );
 
     /**If the skymap will be resized, the sky must be new computed. So this
-    	*function calls explicitly new computing of the skymap.
-    	*It also repositions the InfoBoxes, if they are anchored to a window edge. 
-    	*/
+     * function calls explicitly new computing of the skymap.
+     */
     virtual void resizeEvent( QResizeEvent * );
 
 private slots:
@@ -772,12 +717,6 @@ private:
     	*/
     void drawOverlays( QPixmap *pm );
 
-    /**Draw the Focus, Geo and Time InfoBoxes.  This is called by drawOverlays().
-    	*@param p reference to the QPainter on which to draw (this should be the Sky pixmap).
-    	*@see SkyMap::drawOverlays()
-    	*/
-    void drawBoxes( QPainter &p );
-
     /**Draw symbols at the position of each Telescope currently being controlled by KStars.
     	*@note The shape of the Telescope symbol is currently a hard-coded bullseye.
     	*@param psky reference to the QPainter on which to draw (this should be the Sky pixmap). 
@@ -843,16 +782,6 @@ private:
     	*/
     bool unusablePoint ( const QPointF &p );
 
-    /** Zoom in a large amount or a small amount depending on the keyboard modifier
-     * @param modifier
-     */
-    void zoomIn( const int modifier );
-
-    /** Zoom in a large amount or a small amount depending on the keyboard modifier 
-     * @param modifier
-     */
-    void zoomOut( const int modifier );
-
     /** Calculate the zoom factor for the given keyboard modifier
      * @param modifier
      */
@@ -903,29 +832,21 @@ private:
     bool slewing, clockSlewing;
     bool computeSkymap;  //if false only old pixmap will repainted with bitBlt(), this saves a lot of cpu usage
     bool angularDistanceMode;
-    int idSolInfo, idMessHST, idMoonInfo, idMoonImages, idMessInfo, idNGCHST;
     int scrollCount;
-    double Range;
-    double RefractCorr1[184], RefractCorr2[184];
+    static double RefractCorr1[184];
+    static double RefractCorr2[184];
     double y0;
 
     double m_Scale;
 
     //data for checkVisibility
     bool isPoleVisible;
-    float m_Guidemax;
-    float guideFOV;
-    double XRange, Ymax;
-    double guideXRange;
+    double XRange;
 
-    QString sURL;
-
-    KStars *ks;
     KStarsData *data;
     KSPopupMenu *pmenu;
     QPixmap *sky, *sky2;
-    InfoBoxes  *IBoxes;
-    SkyPoint  Focus, OldFocus, ClickedPoint, FocusPoint, MousePoint, Destination, PreviousClickedPoint;
+    SkyPoint  Focus, ClickedPoint, FocusPoint, MousePoint, Destination;
     SkyObject *ClickedObject, *FocusObject, *TransientObject;
 
     SkyLine AngularRuler; //The line for measuring angles in the map
@@ -936,8 +857,11 @@ private:
     QColor TransientColor;
     unsigned int TransientTimeout;
 
-    //QUATERNION
-    Quaternion m_rotAxis;
+    // InfoBoxes. Used in desctructor to save state
+    InfoBoxWidget* m_timeBox;
+    InfoBoxWidget* m_geoBox;
+    InfoBoxWidget* m_objBox;
+    InfoBoxes*     m_iboxes;
 
     static SkyMap* pinstance;
 
