@@ -51,7 +51,8 @@ const char fileIdSeparator = '_';
 class AbstractDataPluginModelPrivate
 {
  public:
-    AbstractDataPluginModelPrivate( const QString& name, AbstractDataPluginModel * parent )
+    AbstractDataPluginModelPrivate( const QString& name,
+                                    AbstractDataPluginModel * parent )
         : m_parent( parent ),
           m_name( name ),
           m_lastBox(),
@@ -101,14 +102,16 @@ class AbstractDataPluginModelPrivate
     HttpDownloadManager *m_downloadManager;
 };
 
-AbstractDataPluginModel::AbstractDataPluginModel( const QString& name, QObject *parent )
+AbstractDataPluginModel::AbstractDataPluginModel( const QString& name,
+                                                  PluginManager *pluginManager,
+                                                  QObject *parent )
     : QObject(  parent ),
       d( new AbstractDataPluginModelPrivate( name, this ) )
 {
     // Initializing file and download System
     CacheStoragePolicy *storagePolicy = new CacheStoragePolicy( MarbleDirs::localPath()
                                                                 + "/cache/" + d->m_name + '/' );
-    d->m_downloadManager = new HttpDownloadManager( storagePolicy );
+    d->m_downloadManager = new HttpDownloadManager( storagePolicy, pluginManager );
     connect( d->m_downloadManager, SIGNAL( downloadComplete( QString, QString ) ),
              this,                 SLOT( processFinishedJob( QString , QString ) ) );
     
@@ -246,7 +249,7 @@ void AbstractDataPluginModel::downloadItemData( const QUrl& url,
 
     QString id = generateFilename( item->id(), type );
     
-    d->m_downloadManager->addJob( url, id, id );
+    d->m_downloadManager->addJob( url, id, id, DownloadBrowse );
     d->m_downloadingItems.insert( id, item );
     
     connect( item, SIGNAL( destroyed( QObject* ) ), this, SLOT( removeItem( QObject* ) ) );
@@ -260,7 +263,7 @@ void AbstractDataPluginModel::downloadDescriptionFile( const QUrl& url )
         QString name( descriptionPrefix );
         name += QString::number( d->m_descriptionFileNumber );
         
-        d->m_downloadManager->addJob( url, name, name );
+        d->m_downloadManager->addJob( url, name, name, DownloadBrowse );
         d->m_descriptionFileNumber++;
     }
 }
@@ -362,12 +365,7 @@ AbstractDataPluginItem *AbstractDataPluginModel::findItem( const QString& id ) c
 
 bool AbstractDataPluginModel::itemExists( const QString& id ) const
 {
-    if ( findItem( id ) ) {
-        return true;
-    }
-    else {
-        return false;
-    }
+    return findItem( id );
 }
 
 void AbstractDataPluginModel::setItemSettings( QHash<QString,QVariant> itemSettings )
