@@ -13,8 +13,7 @@
 #include "AbstractTile.h"
 #include "AbstractTile_p.h"
 
-#include "MarbleDebug.h"
-
+#include "TileId.h"
 
 namespace Marble
 {
@@ -22,8 +21,7 @@ namespace Marble
 AbstractTilePrivate::AbstractTilePrivate( const TileId& id )
     : m_id( id ),
       m_used( false ),
-      m_state( AbstractTile::TileEmpty ),
-      m_created( QDateTime::currentDateTime() )
+      m_state( AbstractTile::TileEmpty )
 {
 }
 
@@ -71,24 +69,6 @@ AbstractTile::TileState AbstractTile::state() const
     return d->m_state;
 }
 
-void AbstractTile::setState( TileState state )
-{
-    Q_D( AbstractTile );
-    d->m_state = state;
-}
-
-const QDateTime & AbstractTile::created() const
-{
-    Q_D( const AbstractTile );
-    return d->m_created;
-}
-
-void AbstractTile::setCreated( QDateTime created )
-{
-    Q_D( AbstractTile );
-    d->m_created = created;
-}
-
 }
 
 #include "AbstractTile.moc"
