@@ -9,9 +9,8 @@
 // Copyright 2008      Inge Wallin      <inge@lysator.liu.se>
 //
 
-
-#ifndef EQUIRECTSCANLINETEXTUREMAPPER_H
-#define EQUIRECTSCANLINETEXTUREMAPPER_H
+#ifndef MARBLE_EQUIRECTSCANLINETEXTUREMAPPER_H
+#define MARBLE_EQUIRECTSCANLINETEXTUREMAPPER_H
 
 
 #include "AbstractScanlineTextureMapper.h"
@@ -24,8 +23,8 @@ class EquirectScanlineTextureMapper : public AbstractScanlineTextureMapper
     Q_OBJECT
 
  public:
-    explicit EquirectScanlineTextureMapper( TileLoader *tileLoader,
-					    QObject    *parent = 0 );
+    EquirectScanlineTextureMapper( GeoSceneTexture *textureLayer, StackedTileLoader *tileLoader,
+                                   QObject *parent = 0 );
     void mapTexture( ViewParams *viewParams );
 
  private:
