@@ -5,23 +5,28 @@
 // find a copy of this license in LICENSE.txt in the top directory of
 // the source code.
 //
-// Copyright 2008      David Roberts <dvdr18@gmail.com>
+// Copyright 2008      David Roberts  <dvdr18@gmail.com>
+// Copyright 2008      Inge Wallin    <inge@lysator.liu.se>
 //
 
-
-#ifndef SUNCONTROLWIDGET_H
-#define SUNCONTROLWIDGET_H
+#ifndef MARBLE_SUNCONTROLWIDGET_H
+#define MARBLE_SUNCONTROLWIDGET_H
 
 
+#include <QtCore/QDateTime>
+#include <QtCore/QTime>
 #include <QtGui/QDialog>
-#include <QtCore/QDebug>
-#include <QtCore/QTimer>
-
-#include "ui_SunControlWidget.h"
-#include "SunLocator.h"
 
 #include "marble_export.h"
 
+namespace Ui
+{
+    class SunControlWidget;
+}
+
+namespace Marble
+{
+class SunLocator;
 
 class MARBLE_EXPORT SunControlWidget : public QDialog
 {
@@ -50,9 +55,13 @@ class MARBLE_EXPORT SunControlWidget : public QDialog
     void datetimeChanged(QDateTime datetime);
 	
  protected:
+    void showEvent(QShowEvent* event);
     Q_DISABLE_COPY( SunControlWidget )
-    Ui::SunControlWidget m_uiWidget;
-    SunLocator* m_sunLocator;
+
+    Ui::SunControlWidget *m_uiWidget;
+    SunLocator           *m_sunLocator;
 };
 
+}
+
 #endif
