@@ -8,15 +8,17 @@
 // Copyright 2009      Patrick Spendrin <ps_ml@gmx.de>
 //
 
-#ifndef GEODATALINEARRINGPRIVATE_H
-#define GEODATALINEARRINGPRIVATE_H
+#ifndef MARBLE_GEODATALINEARRINGPRIVATE_H
+#define MARBLE_GEODATALINEARRINGPRIVATE_H
 
 #include "GeoDataLineString_p.h"
 
+#include "GeoDataTypes.h"
+
 namespace Marble
 {
 
-class GeoDataLinearRingPrivate : public Marble::GeoDataLineStringPrivate
+class GeoDataLinearRingPrivate : public GeoDataLineStringPrivate
 {
   public:
     GeoDataLinearRingPrivate( TessellationFlags f )
@@ -35,7 +37,12 @@ class GeoDataLinearRingPrivate : public Marble::GeoDataLineStringPrivate
         return copy;
     }
 
-    virtual EnumGeometryId geometryId() const 
+    virtual QString nodeType() const
+    {
+        return GeoDataTypes::GeoDataLinearRingType;
+    }
+
+    virtual EnumGeometryId geometryId() const
     {
         return GeoDataLinearRingId;
     }
@@ -43,4 +50,4 @@ class GeoDataLinearRingPrivate : public Marble::GeoDataLineStringPrivate
 
 } // namespace Marble
 
-#endif //GeoDataLinearRingPRIVATE_H
+#endif
