@@ -18,10 +18,11 @@
 #include <kinputdialog.h>
 #include <kmessagebox.h>
 
-#include "practiceold/testentrymanager.h"
+#include "practice/testentrymanager.h"
 #include <keduvocdocument.h>
 #include <keduvoclesson.h>
 
+#include <KDebug>
 #include <KLocale>
 #include <KStandardDirs>
 #include <KLineEdit>
@@ -32,16 +33,12 @@
 
 #define TENSE_TAG ". "
 
-LanguagePropertiesPage::LanguagePropertiesPage(ParleyDocument *doc, int identifierIndex, QWidget *parent)
-    :QWidget(parent), m_parleyDocument(doc), m_identifierIndex(identifierIndex)
+LanguagePropertiesPage::LanguagePropertiesPage(KEduVocDocument *doc, int identifierIndex, QWidget *parent)
+    :QWidget(parent), m_doc(doc), m_identifierIndex(identifierIndex)
 {
-    m_doc = m_parleyDocument->document();
-
     setupUi(this);
 
     connect(localeComboBox, SIGNAL(currentIndexChanged(const QString&)), this, SLOT(localeChanged(const QString&)));
-    connect(iconComboBox, SIGNAL(currentIndexChanged(int)), this, SLOT(iconChanged(int)));
-    connect(identifierNameLineEdit, SIGNAL(textChanged(const QString&)), this, SLOT(languageNameChanged(const QString&)));
     connect(downloadGrammarButton, SIGNAL(clicked()), this, SLOT(downloadGrammar()));
 
     QStringList languageCodes = KGlobal::locale()->allLanguagesList();
@@ -56,43 +53,11 @@ LanguagePropertiesPage::LanguagePropertiesPage(ParleyDocument *doc, int identifi
         localeComboBox->addItem( language, languageCodeMap.value(language) );
     }
 
-    QString currentIcon;
-
     if (m_identifierIndex < m_doc->identifierCount()) {
         localeComboBox->setCurrentIndex(localeComboBox->findData(
             m_doc->identifier(m_identifierIndex).locale()));
 
         identifierNameLineEdit->setText(m_doc->identifier(m_identifierIndex).name());
-        
-        // icons
-        LanguageSettings currentSettings(m_doc->identifier(m_identifierIndex).locale());
-        currentSettings.readConfig();
-        currentIcon = currentSettings.icon();
-    }
-
-    QStringList countrylist = KGlobal::locale()->allCountriesList();
-    foreach(const QString &code, countrylist) {
-        QString country = KGlobal::dirs()->findResource("locale",
-                QString("l10n/%1/entry.desktop").arg(code));
-        KConfig entry(country, KConfig::SimpleConfig);
-        KConfigGroup group = entry.group("KCM Locale");
-        QString name = group.readEntry("Name", i18n("without name"));
-
-        QString pixmap = country;
-        pixmap.truncate(pixmap.lastIndexOf('/'));
-        pixmap += "/flag.png";
-
-        iconComboBox->addItem(QIcon(pixmap), name, pixmap);
-    }
-    // sort the list by country name
-    iconComboBox->model()->sort(0);
-    // prepend no icon
-    iconComboBox->insertItem(0, i18n("No icon"));
-    int currentIconPosition = iconComboBox->findData(currentIcon);
-    if (currentIconPosition >= 0) {
-        iconComboBox->setCurrentIndex(currentIconPosition);
-    } else {
-        iconComboBox->setCurrentIndex(0);
     }
 
     // keyboard layout
@@ -128,9 +93,13 @@ void LanguagePropertiesPage::setLanguageIdentifierIndex(int newIndex)
     m_identifierIndex = newIndex;
 }
 
+namespace DocumentHelper {
+    void fetchGrammar(KEduVocDocument* doc, int languageIndex);
+}
+
 void LanguagePropertiesPage::downloadGrammar()
 {
-    m_parleyDocument->fetchGrammar(m_identifierIndex);
+    DocumentHelper::fetchGrammar(m_doc, m_identifierIndex);
     loadGrammarFromDocument();
 }
 
@@ -237,10 +206,7 @@ void LanguagePropertiesPage::accept()
     m_doc->identifier(m_identifierIndex).setLocale( locale );
     m_doc->identifier(m_identifierIndex).setName( identifierNameLineEdit->text() );
 
-    QString icon = iconComboBox->itemData(iconComboBox->currentIndex()).toString();
-
     LanguageSettings settings(locale);
-    settings.setIcon(icon);
     if ( keyboardLayoutComboBox->isEnabled() ) {
         settings.setKeyboardLayout( keyboardLayoutComboBox->currentText() );
     }
@@ -248,7 +214,7 @@ void LanguagePropertiesPage::accept()
 
     // articles
     const KEduVocWordFlag::Flags artSing = KEduVocWordFlag::Singular;
-    const KEduVocWordFlag::Flags artDual = KEduVocWordFlag::Dual;
+//    const KEduVocWordFlag::Flags artDual = KEduVocWordFlag::Dual;
     const KEduVocWordFlag::Flags artPlur = KEduVocWordFlag::Plural;
 
     const KEduVocWordFlag::Flags artDef = KEduVocWordFlag::Definite;
@@ -352,12 +318,6 @@ void LanguagePropertiesPage::updateCheckBoxes()
     }
 }
 
-
-void LanguagePropertiesPage::iconChanged(int iconIndex)
-{
-    emit iconSelected( iconComboBox->itemData(iconIndex).toString() );
-}
-
 void LanguagePropertiesPage::localeChanged(const QString & locale)
 {
     identifierNameLineEdit->setText( locale );
@@ -374,7 +334,7 @@ void LanguagePropertiesPage::slotTenseChosen(int index)
 void LanguagePropertiesPage::slotNewTense()
 {
     bool ok;
-    QString getTense = KInputDialog::getText(i18n("Tense Description"), i18n("Enter tense description:"), QString(), &ok, this);
+    QString getTense = KInputDialog::getText(i18n("Tense Name"), i18n("Enter name of tense:"), QString(), &ok, this);
     if (!ok)
         return;
 
@@ -396,7 +356,7 @@ void LanguagePropertiesPage::slotModifyTense()
         str = str.mid(str.indexOf(TENSE_TAG) + QString(TENSE_TAG).length());
 
         bool ok;
-        QString getTense = KInputDialog::getText(i18n("Tense Description"), i18n("Enter tense description:"), str, &ok, this);
+        QString getTense = KInputDialog::getText(i18n("Tense Name"), i18n("Enter name of tense:"), str, &ok, this);
         if (!ok)
             return;
 
